<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

class EasyshopControllerDashboard extends JControllerLegacy
{
	public function loadChartData()
	{
		try
		{
			if (!JSession::checkToken())
			{
				throw new RuntimeException(JText::_('JINVALID_TOKEN'));
			}
			/** @var $model \EasyshopModelDashboard */
			$model         = easyshop('model', 'Dashboard', ES_COMPONENT_ADMINISTRATOR);
			$currencyClass = easyshop('class.currency');
			$utility       = easyshop('class.utility');
			$viewType      = $this->input->getWord('viewType', 'weekly');
			$date          = $this->input->getString('date', '');

			if (!empty($date))
			{
				try
				{
					$date = $utility->getDate($date);
				}
				catch (Exception $e)
				{
					$date = '';
				}
			}

			if (empty($date))
			{
				// Check again
				$date = $utility->getDate();
			}

			$currencyId = (int) $this->input->getInt('currencyId', $currencyClass->getDefault()->get('id'));
			$renderer   = easyshop('renderer');
			$currencyClass->load($currencyId);
			$view = $this->getView('Dashboard', 'html', 'EasyshopView');
			$model->setCurrencyClass($currencyClass);
			$view->setModel($model, true);
			$chartData   = $model->getChartData($viewType, $date, $currencyId);
			$displayData = array_merge($view->getDisplayData(), $this->getDisplayData($chartData));
			$response    = [
				'tiles'           => $renderer->render('dashboard.tile.tile', $displayData),
				'latestOrderHTML' => $renderer->render('order.summary', [
					'orders' => $displayData['latestOrders'],
				]),
				'chart'           => $renderer->render('dashboard.chart.chart', $displayData),
			];
		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response);

		easyshop('app')->close();
	}

	protected function getDisplayData($chartData)
	{

		$displayData = [
			'labels'         => json_encode(array_keys($chartData)),
			'paidAmountJS'   => [],
			'unpaidAmountJS' => [],
			'refundAmountJS' => [],
			'paidAmount'     => 0.0000,
			'unpaidAmount'   => 0.0000,
			'refundAmount'   => 0.0000,
			'paidRate'       => 0.0000,
			'unpaidRate'     => 0.0000,
			'refundRate'     => 0.0000,
		];

		$sumTotal = 0.0000;

		foreach ($chartData as $day => $item)
		{
			$displayData['paidAmountJS'][]   = $item['paid'];
			$displayData['unpaidAmountJS'][] = $item['unpaid'];
			$displayData['refundAmountJS'][] = $item['refund'];
			$displayData['paidAmount']       += $item['paid'];
			$displayData['unpaidAmount']     += $item['unpaid'];
			$displayData['refundAmount']     += $item['refund'];
			$sumTotal                        += $item['paid'] + $item['unpaid'] + $item['refund'];
		}

		if ($sumTotal > 0.0000)
		{
			$displayData['paidRate']   = round($displayData['paidAmount'] / $sumTotal, 4);
			$displayData['unpaidRate'] = round($displayData['unpaidAmount'] / $sumTotal, 4);
			$displayData['refundRate'] = round($displayData['refundAmount'] / $sumTotal, 4);
		}

		return $displayData;
	}
}
