<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('joomla.filesystem.path');

class EasyshopHelper
{
	public static $extension = 'com_easyshop';

	public static function filterArrayToString($value)
	{
		$filter = JFilterInput::getInstance();

		if (is_array($value) || is_object($value))
		{
			$value = (array) $value;
			$value = array_map(function ($v)
			{
				return str_replace(['[', ']'], '', trim($v));
			}, $value);

			$value = join('][', (array) $value);
		}
		elseif (is_string($value))
		{
			$value = trim($value, '[]');
		}

		return '[' . $filter->clean($value) . ']';
	}

	public static function getMediaUserBasePath($type, $userId = 0)
	{
		if ($userId < 1)
		{
			$userId = (int) JFactory::getUser()->id;
		}

		if (easyshop('site'))
		{
			$base = 'assets/' . $type . '/user_customers/' . $userId;
		}
		else
		{
			$base = 'assets/' . $type;
		}

		return $base;
	}

	public static function filterMedia($value, $type, $userId = 0)
	{
		$value = trim($value);

		if (empty($value))
		{
			return $value;
		}

		/** @var $app \JApplicationCms */
		$value = JPath::clean($value, '/');
		$app   = easyshop('app');
		$base  = self::getMediaUserBasePath($type, $userId);

		$file = ES_MEDIA . '/' . $base . '/' . $value;

		if (is_file($file))
		{
			$value = $base . '/' . $value;
		}
		elseif (!empty($value))
		{
			$app->enqueueMessage(JText::sprintf('COM_EASYSHOP_MEDIA_FILE_NO_EXISTS', $value), 'warning');
			$value = '';
		}

		return $value;
	}

	public static function filterMediaImage($value)
	{
		return self::filterMedia($value, 'images');
	}

	public static function filterMediaFile($value)
	{
		return self::filterMedia($value, 'files');
	}

	public static function filterOption($options)
	{
		$data = [];

		if (!empty($options->value) && !empty($options->text))
		{
			foreach ($options->value as $key => $value)
			{
				if (empty($value))
				{
					continue;
				}

				$data[] = [
					'value' => $value,
					'text'  => $options->text[$key],
				];
			}
		}

		return $data;
	}

	public static function getLanguageList()
	{
		static $languages = null;

		if (null === $languages)
		{
			$db    = easyshop('db');
			$query = $db->getQuery(true)
				->select('a.*')
				->from($db->qn('#__languages', 'a'))
				->order('a.ordering ASC');
			$db->setQuery($query);

			$languages = $db->loadObjectList('lang_code');
		}

		return $languages;
	}

	public static function getAllLanguagesFiles($tag = 'en-GB')
	{
		JLoader::import('joomla.filesystem.folder');

		static $allFiles = [];

		if (!isset($allFiles[$tag]))
		{
			$allFiles[$tag] = [];

			if (is_dir(ES_COMPONENT_ADMINISTRATOR . '/language/' . $tag))
			{
				if ($files = JFolder::files(ES_COMPONENT_ADMINISTRATOR . '/language/' . $tag, '\.ini$', false, true))
				{
					$allFiles[$tag] = array_merge($allFiles[$tag], $files);
				}
			}

			$paths = JFolder::folders(JPATH_ROOT . '/modules', '^mod_easyshop', false, true);
			$paths = array_merge(JFolder::folders(JPATH_ADMINISTRATOR . '/modules', '^mod_easyshop', false, true), $paths);

			if (is_dir(JPATH_ROOT . '/plugins/easyshop'))
			{
				$paths = array_merge(JFolder::folders(JPATH_ROOT . '/plugins/easyshop', '[a-zA-Z_0-9]', false, true), $paths);
			}

			if (is_dir(JPATH_ROOT . '/plugins/easyshoppayment'))
			{
				$paths = array_merge(JFolder::folders(JPATH_ROOT . '/plugins/easyshoppayment', '[a-zA-Z_0-9]', false, true), $paths);
			}

			if (is_dir(JPATH_ROOT . '/plugins/easyshopshipping'))
			{
				$paths = array_merge(JFolder::folders(JPATH_ROOT . '/plugins/easyshopshipping', '[a-zA-Z_0-9]', false, true), $paths);
			}

			if (!empty($paths))
			{
				foreach ($paths as $path)
				{
					if (is_dir($path . '/language/' . $tag))
					{
						if ($files = JFolder::files($path . '/language/' . $tag, '\.ini$', false, true))
						{
							$allFiles[$tag] = array_merge($allFiles[$tag], $files);
						}
					}
				}
			}
		}

		return $allFiles[$tag];
	}
}
