<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

use ES\Currency;

class EasyshopModelDashboard extends JModelLegacy
{
	protected $currencyClass;

	protected function triggerQuery($query, $queryName)
	{
		$state = easyshop('state');
		$scope = $state->get('scope');
		$state->set('scope', 'DASHBOARD_MODEL_QUERY_' . strtoupper($queryName));
		easyshop('app')->triggerEvent('onEasyshopDashboardModelPrepareQuery', [$query]);
		$state->set('scope', $scope);
	}

	protected function getOrderBaseQuery($currencyId)
	{
		$db    = $this->getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->from($db->qn('#__easyshop_orders', 'a'))
			->where('a.state <> -2 AND a.currency_id = ' . (int) $currencyId);
		$this->triggerQuery($query, 'ORDER');

		return [$db, $query];
	}

	public function getChartData($viewType = 'weekly', $date, $currencyId)
	{
		list($db, $query) = $this->getOrderBaseQuery($currencyId);
		$nowDate = clone $date;

		if ($viewType == 'yearly')
		{
			$sub       = 'P1M';
			$format    = 'F';
			$end       = 12;
			$fromWDate = $date->sub(new DateInterval('P1Y'));
		}
		elseif ($viewType == 'monthly')
		{
			$sub       = 'P1D';
			$format    = 'M, d Y';
			$end       = (int) $date->format('t');
			$fromWDate = $date->sub(new DateInterval('P1M'));
		}
		else
		{
			$sub       = 'P1D';
			$format    = 'l';
			$end       = 7;
			$fromWDate = $date->sub(new DateInterval('P1W'));
		}

		$query->where('DATE(a.created_date) BETWEEN DATE('
			. $db->q($fromWDate->toSql()) . ') AND DATE('
			. $db->q($nowDate->toSql()) . ')'
		);

		$nowDate->add(new DateInterval($sub));

		$orders = [];

		for ($i = 0; $i < $end; $i++)
		{
			$label          = strtoupper($nowDate->sub(new DateInterval($sub))->format($format));
			$label          = JText::_($label);
			$orders[$label] = [
				'orders' => [],
				'paid'   => 0.0000,
				'unpaid' => 0.0000,
				'refund' => 0.0000,
			];
		}

		$db->setQuery($query);

		if ($orderIds = $db->loadColumn())
		{
			/** @var $orderClass \ES\Order */

			$orderClass = \easyshop('class.Order');

			foreach ($orderIds as $orderId)
			{
				if ($orderClass->load($orderId))
				{
					$orderDate = JFactory::getDate($orderClass->get('created_date'))->format($format);
					$orderDate = JText::_(strtoupper($orderDate));

					if (isset($orders[$orderDate]))
					{
						$orders[$orderDate]['orders'][] = clone $orderClass;

						switch ((int) $orderClass->get('payment_status'))
						{
							case 0:
								$orders[$orderDate]['unpaid'] += $orderClass->total_price;
								break;

							case 1:
								$orders[$orderDate]['paid'] += $orderClass->total_paid;
								break;

							case 2:
								$orders[$orderDate]['refund'] += $orderClass->total_price;
								break;
						}
					}
				}
			}
		}

		return array_reverse($orders);
	}

	protected function getOrdersModel()
	{
		/** @var $orderModels \EasyshopModelOrders */
		$ordersModel = easyshop('model', 'Orders', ES_COMPONENT_ADMINISTRATOR);
		$ordersModel->setState('filter.published', '');
		$ordersModel->setState('list.ordering', 'a.created_date');
		$ordersModel->setState('list.direction', 'DESC');
		$ordersModel->setState('filter.currency_id', $this->getCurrencyClass()->get('id'));
		$ordersModel->setState('filter.vendor_id', 0);
		$ordersModel->setState('list.start', 0);

		return $ordersModel;
	}

	public function getLatestOrders()
	{
		$ordersModel = $this->getOrdersModel();
		$ordersModel->setState('list.limit', (int) easyshop('config', 'latest_order_num', 10));

		return $ordersModel->getItems();
	}

	public function setCurrencyClass(Currency $currencyClass = null)
	{
		$this->currencyClass = $currencyClass;
	}

	public function getCurrencyClass()
	{
		if (!isset($this->currencyClass))
		{
			$this->currencyClass = easyshop('class.currency')->getDefault();
		}

		return $this->currencyClass;
	}

	public function getOrdersThisMonth()
	{
		$date   = easyshop('class.utility')->getDate();
		$toDate = $date->format('Y-m-d H:i:s', true);
		$m      = (int) $date->format('m', true);

		while ($m == (int) $date->format('m', true))
		{
			$date->sub(new DateInterval('P1D'));
		}

		$date->add(new DateInterval('P1D'));
		$fromDate    = $date->format('Y-m-d H:i:s', true);
		$ordersModel = $this->getOrdersModel();
		$ordersModel->setState('filter.from_date', $fromDate);
		$ordersModel->setState('filter.to_date', $toDate);
		$results = [
			'fromDate'   => $fromDate,
			'toDate'     => $toDate,
			'items'      => [],
			'saleItems'  => [],
			'totalPrice' => 0.0000,
			'totalPaid'  => 0.0000,
		];

		if ($items = $ordersModel->getItems())
		{
			$orderClass = easyshop('class.Order');

			foreach ($items as &$item)
			{
				$orderClass->load($item->id);
				$item                  = clone $orderClass;
				$results['totalPrice'] += (float) $item->total_price;
				$results['totalPaid']  += (float) $item->total_paid;

				if ($item->total_paid > 0.0000)
				{
					$results['saleItems'][] = $item;
				}
			}

			$results['items'] = $items;

		}

		return $results;
	}

	public function getBestProducts()
	{
		$db    = $this->getDbo();
		$query = $db->getQuery(true)
			->select('a.id, a.name, a2.product_price AS price, SUM(a2.quantity) AS orderQuantity, a3.currency_id')
			->from($db->qn('#__easyshop_products', 'a'))
			->innerJoin($db->qn('#__easyshop_order_products', 'a2') . ' ON a2.product_id = a.id')
			->innerJoin($db->qn('#__easyshop_orders', 'a3') . ' ON a3.id = a2.order_id')
			->where('a3.payment_status = 1')
			->group('a.id, a3.currency_id')
			->order('orderQuantity DESC');
		$this->triggerQuery($query, 'BEST_PRODUCT');
		$db->setQuery($query, 0, 9);

		return $db->loadObjectList();
	}

	public function getBestCustomers()
	{
		$db    = $this->getDbo();
		$query = $db->getQuery(true)
			->select('COUNT(a.user_id) AS orderQuantity, a3.name')
			->from($db->qn('#__easyshop_orders', 'a'))
			->innerJoin($db->qn('#__easyshop_users', 'a2') . ' ON a2.id = a.user_id')
			->innerJoin($db->qn('#__users', 'a3') . ' ON a3.id = a2.user_id')
			->where('a.payment_status = 1 AND a.user_id > 0')
			->group('a.user_id, a.currency_id')
			->order('orderQuantity DESC');
		$this->triggerQuery($query, 'BEST_CUSTOMER');
		$db->setQuery($query, 0, 9);

		return $db->loadObjectList();
	}
}
