<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

class JFormFieldUI_DateTimePicker extends JFormField
{
	protected $type = 'UI_DateTimePicker';
	protected $format = '%Y-%m-%d %H:%M:%S';
	protected $dateFormat;
	protected $timeFormat;
	protected $filter;
	protected $todayButton;
	protected $showTime;
	protected $yearRange;
	protected $changeYear;
	protected $changeMonth;
	protected $numberOfMonths;
	protected $controlType;
	protected $inline;

	public function __get($name)
	{
		switch ($name)
		{
			case 'dateFormat':
			case 'timeFormat':
			case 'filter':
			case 'todayButton':
			case 'showTime':
			case 'yearRange':
			case 'changeYear':
			case 'changeMonth':
			case 'numberOfMonths':
			case 'controlType':
			case 'inline':
				return $this->$name;
		}

		return parent::__get($name);
	}

	public function __set($name, $value)
	{
		switch ($name)
		{
			case 'timeFormat':
			case 'numberOfMonths':
				$this->$name = (int) $value;
				break;

			case 'dateFormat':
			case 'filter':
			case 'todayButton':
			case 'showTime':
			case 'yearRange':
			case 'changeYear':
			case 'changeMonth':
			case 'controlType':
			case 'inline':
				$this->$name = (string) $value;
				break;

			default:
				parent::__set($name, $value);
		}
	}

	public function setup(SimpleXMLElement $element, $value, $group = null)
	{
		$return = parent::setup($element, $value, $group);

		if ($return)
		{
			$config               = easyshop('config');
			$this->dateFormat     = (string) $this->element['dateFormat'] ? (string) $this->element['dateFormat'] : $config->get('php_date_format', 'Y-m-d');
			$this->timeFormat     = (int) $this->element['timeFormat'] ? (int) $this->element['timeFormat'] : $config->get('php_time_format', 'H:i:s');
			$this->filter         = (string) $this->element['filter'] ? (string) $this->element['filter'] : '';
			$this->todayButton    = (string) $this->element['todayButton'] ? (string) $this->element['todayButton'] : 'true';
			$this->showTime       = (string) $this->element['showTime'] ? (string) $this->element['showTime'] : 'true';
			$this->yearRange      = strlen((string) $this->element['yearRange']) ? (string) $this->element['yearRange'] : 'c-10:c+10';
			$this->changeYear     = strlen((string) $this->element['changeYear']) ? (string) $this->element['changeYear'] : 'false';
			$this->changeMonth    = strlen((string) $this->element['changeMonth']) ? (string) $this->element['changeMonth'] : 'false';
			$this->numberOfMonths = strlen((string) $this->element['numberOfMonths']) ? (string) $this->element['numberOfMonths'] : '1';
			$this->controlType    = strlen((string) $this->element['controlType']) ? (string) $this->element['controlType'] : 'slider';
			$this->inline         = strlen((string) $this->element['inline']) ? (string) $this->element['inline'] : 'false';
		}

		return $return;
	}


	protected function getInput()
	{
		$config   = JFactory::getConfig();
		$user     = JFactory::getUser();
		$db       = JFactory::getDbo();
		$nullDate = $db->getNullDate();

		if ($this->showTime === 'false' || $this->showTime === '0')
		{
			$this->format = '%Y-%m-%d';
		}

		// If a known filter is given use it.
		switch (strtoupper($this->filter))
		{
			case 'SERVER_UTC':
				// Convert a date to UTC based on the server timezone.
				if ($this->value && $this->value != $nullDate)
				{
					// Get a date object based on the correct timezone.
					$date = JFactory::getDate($this->value, 'UTC');
					$date->setTimezone(new DateTimeZone($config->get('offset')));

					// Transform the date string.
					$this->value = $date->format('Y-m-d H:i:s', true, false);
				}

				break;

			case 'USER_UTC':
				// Convert a date to UTC based on the user timezone.
				if ($this->value && $this->value != $nullDate)
				{
					// Get a date object based on the correct timezone.
					$date = JFactory::getDate($this->value, 'UTC');
					$date->setTimezone($user->getTimezone());

					// Transform the date string.
					$this->value = $date->format('Y-m-d H:i:s', true, false);
				}

				break;
		}

		// Format value when not nulldate ('0000-00-00 00:00:00'), otherwise blank it as it would result in 1970-01-01.
		if ($this->value && $this->value != $nullDate && strtotime($this->value) !== false)
		{
			$tz = date_default_timezone_get();
			date_default_timezone_set('UTC');
			$this->value = strftime($this->format, strtotime($this->value));
			date_default_timezone_set($tz);
		}
		else
		{
			$this->value = '';
		}

		/**         @var \ES\Utility $utilityClass */
		$utilityClass = easyshop('class.utility');
		$options      = array(
			'dateFormat'     => $this->dateFormat,
			'timeFormat'     => $this->timeFormat,
			'inline'         => in_array(strtolower($this->inline), ['true', '1']),
			'jsDateFormat'   => $utilityClass->convertPHPToJSDateTimeFormat($this->dateFormat),
			'jsTimeFormat'   => $utilityClass->convertPHPToJSDateTimeFormat($this->timeFormat),
			'todayButton'    => $this->todayButton,
			'showTime'       => $this->showTime,
			'yearRange'      => $this->yearRange,
			'changeYear'     => $this->changeYear,
			'changeMonth'    => $this->changeMonth,
			'numberOfMonths' => $this->numberOfMonths,
			'controlType'    => $this->controlType,
			'required'       => $this->required,
			'onchange'       => $this->onchange,
			'hint'           => $this->hint ? JText::_($this->hint) : '',
		);

		return JHtml::_('easyshop.datetimePicker', $this->id, $this->name, $this->value, $options);
	}
}
