<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;
JLoader::import('easyshop.model.list');

use ES\Model\ModelList;

class EasyshopModelProducts extends ModelList
{
	protected $searchField = 'name';
	protected $searchMetaData = true;

	public function __construct(array $config)
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = [
				'id', 'a.id',
				'category_id', 'a.category_id',
				'sku', 'a.sku',
				'name', 'a.name',
				'state', 'a.state',
				'stock', 'a.stock',
				'ordering', 'a.ordering',
				'hits', 'a.hit',
				'created_date', 'a.created_date',
				'modified', 'a.modified',
				'price', 'a.price',
				'language', 'a.language',
				'vendor_id', 'a.vendor_id',
				'published', 'category_name',
			];
		}
		parent::__construct($config);
	}

	protected function populateState($ordering = null, $direction = null)
	{
		$search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$published = $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '');
		$this->setState('filter.published', $published);

		$categoryId = $this->getUserStateFromRequest($this->context . '.filter.category_id', 'filter_category_id', '');
		$this->setState('filter.category_id', $categoryId);

		$brandId = $this->getUserStateFromRequest($this->context . '.filter.brand_id', 'filter_brand_id', '');
		$this->setState('filter.brand_id', $brandId);

		$language = $this->getUserStateFromRequest($this->context . '.filter.language', 'filter_language', '');
		$this->setState('filter.language', $language);

		$prices = $this->getUserStateFromRequest($this->context . '.filter.prices', 'filter_prices', '');
		$this->setState('filter.prices', $prices);

		$tags = $this->getUserStateFromRequest($this->context . '.filter.tags', 'filter_tags', [], 'array');
		$this->setState('filter.tags', $tags);

		$vendorId = $this->getUserStateFromRequest($this->context . '.filter.vendor_id', 'filter_vendor_id', '');
		$this->setState('filter.vendor_id', $vendorId);

		parent::populateState('a.id', 'desc');
	}

	public function getStoreId($id = '')
	{
		$id .= ':' . $this->getState('filter.search');
		$id .= ':' . $this->getState('filter.published');
		$id .= ':' . $this->getState('filter.category_id');
		$id .= ':' . $this->getState('filter.include_sub_categories');
		$id .= ':' . $this->getState('filter.brand_id');
		$id .= ':' . $this->getState('filter.language');
		$id .= ':' . $this->getState('filter.prices');
		$id .= ':' . $this->getState('filter.vendor_id');
		$id .= ':' . serialize($this->getState('filter.tags'));

		return parent::getStoreId($id);
	}

	protected function getListQuery()
	{
		$db    = $this->getDbo();
		$query = parent::getListQuery();
		$query->select(
			$this->getState('list.select',
				'DISTINCT a.id, a.language, a.category_id, a.ordering, a.price, a.created_date, a.hits, u.name AS author, '
				. 'uu.name AS editor, l.title AS language_title, l.image AS language_image, c.title AS category_name'
			)
		)
			->from($db->qn('#__easyshop_products', 'a'))
			->leftJoin($db->qn('#__users', 'u') . ' ON u.id = a.created_by')
			->leftJoin($db->qn('#__categories', 'c') . ' ON c.id = a.category_id')
			->leftJoin($db->qn('#__users', 'uu') . ' ON uu.id = a.checked_out')
			->leftJoin($db->qn('#__languages', 'l') . ' ON l.lang_code = a.language');
		$categoryId           = $this->getState('filter.category_id');
		$includeSubCategories = $this->getState('filter.include_sub_categories');

		if (is_numeric($categoryId))
		{
			if (!is_numeric($includeSubCategories) || (int) $includeSubCategories > 0)
			{
				$categoryTable = JTable::getInstance('Category', 'JTable');
				$categoryTable->load($categoryId);
				$rgt = $categoryTable->rgt;
				$lft = $categoryTable->lft;
				$query->where('c.lft >= ' . (int) $lft)
					->where('c.rgt <= ' . (int) $rgt);
			}
			else
			{
				$query->where('a.category_id = ' . (int) $categoryId);
			}
		}

		$brandId = $this->getState('filter.brand_id');

		if (is_numeric($brandId))
		{
			$query->where('a.brand_id = ' . (int) $brandId);
		}

		$language = $this->getState('filter.language');
		$view     = easyshop('app')->input->get('view');

		if (easyshop('site') && $view !== 'products')
		{
			$query->where('a.display_in_search = 1');

			if (easyshop('config', 'hide_product_off_sale', 0))
			{
				$nullDate = $db->q($db->getNullDate());
				$now      = $db->q(\JFactory::getDate()->toSql());
				$query->where('
				CASE WHEN 
					a.sale_from_date <> ' . $nullDate . ' AND a.sale_to_date <> ' . $nullDate
					. ' THEN ' . $now . ' BETWEEN a.sale_from_date AND a.sale_to_date'
					. ' ELSE 1 END
				');
			}

			if ($language)
			{
				$query->where('a.language in (' . $db->q(JFactory::getLanguage()->getTag()) . ',' . $db->q('*') . ')');
			}

			$prices = $this->getState('filter.prices');

			if (!empty($prices) && strpos($prices, '-') !== false)
			{
				$parts = explode('-', $prices, 2);
				$min   = (float) $parts[0];
				$max   = (float) $parts[1];

				if ($min > 0.00 && $max < 0.01)
				{
					$query->where('a.price > ' . $min);
				}
				else
				{
					$query->where('(a.price BETWEEN ' . $min . ' AND ' . $max . ')');
				}
			}
		}
		elseif ($language)
		{
			$query->where('a.language = ' . $db->q($language));
		}

		$tags = $this->getState('filter.tags');

		if (!empty($tags))
		{
			if (!is_array($tags) && strpos($tags, '|') !== false)
			{
				$tags = explode('|', $tags);
			}
			else
			{
				$tags = [$tags];
			}

			foreach ($tags as &$tag)
			{
				$tag = $db->q($db->escape(trim($tag), true));
			}

			$tags = join(',', $tags);
			$query->innerJoin($db->qn('#__easyshop_tag_items', 'tagItem') . ' ON tagItem.item_id = a.id')
				->innerJoin($db->qn('#__easyshop_tags', 'tag') . ' ON tag.id = tagItem.tag_id')
				->where('tag.context = ' . $db->q('com_easyshop.product'))
				->where('(tag.name IN (' . $tags . ') OR tag.alias IN (' . $tags . '))');
		}

		$vendorId = $this->getState('filter.vendor_id');

		if (is_numeric($vendorId))
		{
			$query->where('a.vendor_id = ' . (int) $vendorId);
		}

		$this->standardFilter($db, $query);

		return $query;

	}

	public function getItems()
	{
		$products = [];

		if ($items = parent::getItems())
		{
			/** @var $product \ES\Product */
			$product = easyshop('class.product');

			foreach ($items as $item)
			{
				$fields = (array) $item;
				$item   = $product->getItem($item->id);

				foreach ($fields as $name => $value)
				{
					if (!isset($item->{$name}))
					{
						$item->{$name} = $value;
					}
				}

				$products[] = $item;
			}
		}

		return $products;
	}
}
