<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.table.abstract');

use ES\Table\TableAbstract;

class EasyshopTableCustomField extends TableAbstract
{
	protected function getTableDBName()
	{
		return '#__easyshop_customfields';
	}

	public function check()
	{
		/** @var $customField \ES\CustomField */
		$customField = easyshop('class.customField');

		if (!$customField->isValidReflector($this->reflector))
		{
			$this->setError(JText::_('COM_EASYSHOP_WARNING_PROVIDE_VALID_REFLECTOR'));

			return false;
		}

		$db    = $this->getDbo();
		$query = $db->getQuery(true)
			->select('COUNT(a.id)')
			->from($db->qn('#__easyshop_customfields', 'a'))
			->where('a.reflector = ' . $db->q($this->reflector))
			->where('a.field_name = ' . $db->q($this->field_name));

		if ($this->id)
		{
			$query->where('a.id <> ' . (int) $this->id);
		}

		$db->setQuery($query);

		if (empty($this->field_name) || $db->loadResult())
		{
			$this->setError(JText::_('COM_EASYSHOP_ERROR_FIELD_NAME_UNIQUE'));

			return false;
		}

		return parent::check();
	}

	public function delete($pk = null)
	{
		$table = clone $this;

		if ($table->load($pk) && $table->get('protected'))
		{
			$this->setError(JText::plural('COM_EASYSHOP_ERROR_CUSTOMFIELD_HAS_PROTECTED', $table->get('name'), $pk));

			return false;
		}

		return parent::delete($pk);
	}

	public function store($updateNulls = false)
	{
		if ($this->protected)
		{
			if ((int) $this->state !== 1)
			{
				$this->state = 1;
			}

			$this->field_name = null;
		}

		return parent::store($updateNulls);
	}

}
