<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.table.abstract');

use ES\Table\TableAbstract;

class EasyshopTableProduct extends TableAbstract
{
	protected function getTableDBName()
	{
		return '#__easyshop_products';
	}

	public function check()
	{
		if (!empty($this->metakey))
		{
			$badCharacters = ["\n", "\r", "\"", "<", ">"];
			$afterClean    = Joomla\String\StringHelper::str_ireplace($badCharacters, "", $this->metakey);
			$keys          = explode(',', $afterClean);
			$cleanKeys     = [];

			foreach ($keys as $key)
			{
				if (trim($key))
				{
					$cleanKeys[] = trim($key);
				}
			}

			$this->metakey = implode(", ", $cleanKeys);
		}

		if (!$this->id)
		{
			if (!$this->getRules())
			{
				$rules = $this->getDefaultAssetValues('com_easyshop');
				$this->setRules($rules);
			}
		}

		if (empty($this->sale_from_date))
		{
			$this->sale_from_date = $this->_db->getNullDate();
		}

		if (empty($this->sale_to_date))
		{
			$this->sale_to_date = $this->_db->getNullDate();
		}

		return parent::check();
	}

	public function store($updateNulls = false)
	{
		$table = JTable::getInstance('Product', 'EasyshopTable', ['dbo' => $this->getDbo()]);

		if ($table->load(['alias' => $this->alias, 'category_id' => $this->category_id]) && ($table->id != $this->id || $this->id == 0))
		{
			$this->setError(JText::_('COM_EASYSHOP_ERROR_PRODUCT_UNIQUE_ALIAS'));

			return false;
		}

		return parent::store($updateNulls);
	}

	protected function _getAssetName()
	{
		$k = $this->_tbl_key;

		return 'com_easyshop.product.' . (int) $this->$k;
	}

	protected function _getAssetTitle()
	{
		return $this->name;
	}

	protected function _getAssetParentId(JTable $table = null, $id = null)
	{
		$assetId = null;

		if ($this->category_id)
		{
			$query = $this->_db->getQuery(true)
				->select($this->_db->quoteName('asset_id'))
				->from($this->_db->quoteName('#__categories'))
				->where($this->_db->quoteName('id') . ' = ' . (int) $this->category_id);
			$this->_db->setQuery($query);

			if ($result = $this->_db->loadResult())
			{
				$assetId = (int) $result;
			}
		}

		if ($assetId)
		{
			return $assetId;
		}
		else
		{
			return parent::_getAssetParentId($table, $id);
		}
	}

	protected function getDefaultAssetValues($component)
	{
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select($db->quoteName('id'))
			->from($db->quoteName('#__assets'))
			->where($db->quoteName('name') . ' = ' . $db->quote($component));
		$db->setQuery($query);
		$assetId = (int) $db->loadResult();

		return JAccess::getAssetRules($assetId);
	}

	public function delete($pk = null)
	{
		$result = parent::delete($pk);

		if ($result && $pk)
		{
			$pk    = (int) $pk;
			$db    = easyshop('db');
			$query = $db->getQuery(true)
				->delete($db->qn('#__easyshop_medias'))
				->where($db->qn('product_id') . ' = ' . $pk);
			$db->setQuery($query)
				->execute();

			/** @var $customField \ES\CustomField */
			$customField = easyshop('class.customField');
			$customField->removeValues('com_easyshop.product.customfield', $pk);
		}

		return $result;
	}
}
