<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

use ES\Helper\Navbar;
use ES\View\ViewLegacy;

JLoader::import('easyshop.view.legacy');
JLoader::import('joomla.filesystem.folder');
JLoader::import('helpers.media', ES_COMPONENT_ADMINISTRATOR);

class EasyshopViewMedia extends ViewLegacy
{
	protected $uri;
	protected $directory;
	protected $viewType;
	protected $breadcrumbs = [];
	protected $files = [];
	protected $isFile = false;
	protected $allowedFiles;

	public function display($tpl = null)
	{
		$rootUrl   = JUri::root(true);
		$app       = easyshop('app');
		$type      = $app->input->getWord('media_type', 'image');
		$directory = $app->getUserStateFromRequest('com_easyshop.media_' . $type . '_path', 'media_path', '', 'path');
		$directory = preg_replace('/^\/+/', '', $directory);
		$mediaUrl  = EasyshopHelperMedia::getLink($directory, $type);
		$mediaAjax = EasyshopHelperMedia::getLink($directory, $type, 'media.upload');
		$user      = easyshop('class.user');
		$extraPath = (!empty($directory) ? $directory : '');
		$isFile    = $type === 'file' && JPluginHelper::isEnabled('easyshop', 'file');
		$isSite    = easyshop('site');

		if ($isSite)
		{
			$extraPath = rtrim('user_customers/' . $user->get()->id . '/' . $extraPath, '/');
		}

		if ($isFile)
		{
			$basePath     = ES_MEDIA . '/assets/files/' . $extraPath;
			$plugin       = easyshop('plugin', 'File');
			$allowedFiles = $plugin->params->get('allowed_files', 'zip|doc|docx|pdf|xls|txt|gz|gzip|rar|jpg|gif|tar.gz|xlsx|pps|csv|bmp|epg|ico|odg|odp|ods|odt|png|ppt|swf|xcf|wmv|avi|mkv|mp3|ogg|flac|wma|fla|flv|mp4|wav|aac|mov|epub');
		}
		else
		{
			$basePath     = ES_MEDIA . '/assets/images/' . $extraPath;
			$allowedFiles = 'svg|jpg|jpeg|gif|png|SVG|JPG|JPEG|GIF|PNG';
		}

		$basePath = rtrim($basePath, '/');
		$paths    = [];

		if (JFolder::exists($basePath))
		{
			$exclude = [
				'.svn',
				'CVS',
				'.DS_Store',
				'__MACOSX',
				'.idea',
				'.tmp',
				'.git',
				'thumbs',
			];

			if ($isSite)
			{
				$excludeFilter = [
					'^\..*',
				];
			}
			else
			{
				$excludeFilter = [
					'user_customers',
				];
			}

			$paths = (array) JFolder::folders($basePath, '.', false, false, $exclude, $excludeFilter);
			$files = JFolder::files($basePath, '.*(' . $allowedFiles . ')$', false, true);

			if ($isFile)
			{
				foreach ($files as &$file)
				{
					$temp       = new stdClass;
					$file       = JPath::clean($file, '/');
					$temp->file = str_replace(JPath::clean(ES_MEDIA, '/') . '/', '', $file);
					$file       = $temp;
				}

				$this->files = $files;
			}
			else
			{
				//@since 1.1.6
				/** @var \ES\Media $mediaClass */
				$mediaClass = easyshop('class.media');

				foreach ($files as &$file)
				{
					$file = str_replace(JPath::clean(ES_MEDIA, '/') . '/', '', $file);
					$file = $mediaClass->getFullImages($file);
				}

				$this->files = $files;
			}
		}
		elseif (!empty($directory))
		{
			$directory = basename($directory);
		}

		$parentPath = empty($directory) ? '' : $directory . '/';

		foreach ($paths as &$path)
		{
			$p    = $path;
			$path = new JObject;
			$path->set('url', EasyshopHelperMedia::getLink($parentPath . $p, $type));
			$path->set('title', $p);
			$path->set('path', $p);
		}

		$breadcrumbs = [];

		if (!empty($directory))
		{
			$breadcrumbs = (array) explode('/', $directory);
			$linkPath    = '';

			foreach ($breadcrumbs as &$breadcrumb)
			{
				$linkPath   .= '/' . $breadcrumb;
				$linkPath   = ltrim($linkPath, '/');
				$breadcrumb = [
					'link'  => EasyshopHelperMedia::getLink($linkPath, $type),
					'title' => $breadcrumb,
				];
			}
		}

		$this->breadcrumbs = $breadcrumbs;
		$this->uri         = new JObject;
		$this->uri->set('media.url', $mediaUrl);
		$this->uri->set('media.ajax', $mediaAjax . '&returnAjax=' . base64_encode($mediaAjax));
		$this->directory = new JObject;
		$this->directory->set('base', $directory);
		$this->directory->set('path.url', $rootUrl . '/media/com_easyshop/assets/' . ($isFile ? 'files' : 'images'));
		$this->directory->set('list.path', $paths);

		if ($this->getLayout() != 'modal' && easyshop('app')->input->getString('tmpl') != 'component')
		{
			echo Navbar::render();
			$this->addToolbar();
		}

		$this->isFile       = $isFile;
		$this->allowedFiles = $allowedFiles;

		parent::display($tpl);
	}

	protected function addToolbar()
	{
		$user = JFactory::getUser();
		JToolbarHelper::title(JText::_('COM_EASYSHOP_MEDIA_MANAGE'));

		if ($user->authorise('core.admin', 'com_easyshop') || $user->authorise('core.options', 'com_easyshop'))
		{
			JToolbarHelper::preferences('com_easyshop');
		}
	}

}
