<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;
JLoader::import('easyshop.view.item');

use ES\View\ViewItem;
use Joomla\Registry\Registry;

class EasyshopViewOrder extends ViewItem
{
	protected $payment = null;
	protected $order = null;

	protected function addToolbar()
	{
		easyshop('app')->input->set('hidemainmenu', true);
		JToolbarHelper::title(\JText::sprintf('COM_EASYSHOP_ORDER_EDIT', $this->item->order_code));

		if ($this->item->id)
		{
			$bar = JToolbar::getInstance();
			$bar->appendButton('Custom', '<a href="#" id="es-print-order" class="btn btn-small"><i class="icon-print"></i> '
				. JText::_('COM_EASYSHOP_PRINT_ORDER') . '</a>', 'email');
			JHtml::_('easyshop.printOrder', $this->item->id, JText::sprintf('COM_EASYSHOP_ORDER_PRINT_TITLE_FORMAT', $this->item->order_code));
			/**
			 * @var $emailsModel \EasyshopModelEmails
			 * @var $emailModel  \EasyshopModelEmail
			 */
			$emailsModel = easyshop('model', 'Emails');
			$emailsModel->setState('filter.published', 1);
			$emailsModel->setState('filter.send_on', ['[ON_NEW_ORDER]', '[ON_ORDER_CHANGE_STATE]', '[ON_ORDER_CHANGE_PAYMENT]']);
			$emailsModel->setState('list.select', 'a.id, a.name');

			if ($items = $emailsModel->getItems())
			{
				$emailModel = easyshop('model', 'Email');
				$form       = $emailModel->getForm();
				$form->setFieldAttribute('send_from_name', 'class', 'uk-input');
				$form->setFieldAttribute('send_from_email', 'class', 'uk-input');
				$form->setFieldAttribute('send_subject', 'class', 'uk-input');
				$form->setFieldAttribute('send_to_emails', 'class', 'uk-textarea');

				$selectBox = '<div class="uk-modal-header"><div class="uk-flex">'
					. '<select id="es-emails">'
					. '<option value="">' . JText::_('COM_EASYSHOP_EMAIL_SELECT') . '</option>';

				foreach ($items as $item)
				{
					$selectBox .= '<option value="' . $item->id . '">' . $item->name . '</option>';
				}

				$selectBox .= '</select><a id="es-send-link" class="uk-button uk-button-primary uk-button-small uk-margin-left">'
					. '<span uk-icon="icon: mail"></span>' . JText::_('COM_EASYSHOP_SEND')
					. '</a></div><a class="uk-modal-close-full" uk-close></a></div>';
				$addOns    = easyshop('class.addon')->getAddons('email');
				$addOnHtml = '<div id="es-addon-area">';

				foreach ($addOns as $element => $addOnForm)
				{
					$groups = $addOnForm->getGroup('');

					if (count($groups))
					{
						$addOnHtml .= '<h4 class="uk-h5 uk-heading-bullet uk-margin-remove">'
							. JText::_('PLG_EASYSHOP_' . strtoupper($element) . '_ADDON_LABEL') . '</h4>';

						foreach ($groups as $field)
						{
							$addOnHtml .= $field->renderField();
						}
					}
				}

				$addOnHtml .= '</div>';
				echo '<div id="es-email-modal" class="uk-modal-full" uk-modal>'
					. '<div class="uk-modal-dialog uk-modal-body">'
					. $selectBox . '<form method="post" action="'
					. JRoute::_('index.php?option=com_easyshop&view=order&layout=edit&id=' . $this->item->id, false)
					. '" class="uk-form-horizontal uk-margin"><input type="hidden" name="task" value="order.sendEmail"/>'
					. $form->renderFieldset('templates') . $addOnHtml . JHtml::_('form.token') . '</form></div></div>';

				$bar->appendButton('Custom', '<a href="#" class="btn btn-small" uk-toggle="target: #es-email-modal"><i class="icon-mail"></i> '
					. JText::_('COM_EASYSHOP_EMAIL') . '</a>', 'email');

				easyshop('doc')->addScriptDeclaration('
					_es.$(document).ready(function($){					
						$("#es-emails").on("change", function(){
							var el = $(this);							
							if(el.val() != ""){
								_es.ajax(_es.getData("uri").pathRoot + "/administrator/index.php?option=com_easyshop&task=order.loadEmailTemplate", {
									easyshopArea: $("#es-email-modal"),
									emailId: el.val(),
									orderId: ' . (int) $this->item->id . '
								}, function(response){
									var form = $("#es-email-modal form");
									form.find("[name=\'jform[send_from_name]\']").val(response.data.send_from_name);										
									form.find("[name=\'jform[send_from_email]\']").val(response.data.send_from_email);										
									form.find("[name=\'jform[send_to_emails]\']").val(response.data.send_to_emails);										
									form.find("[name=\'jform[send_subject]\']").val(response.data.send_subject);										
									form.find("[name=\'jform[send_body]\']").val(response.data.send_body);
									form.find("#es-addon-area").html(response.data.addon);
									if (Joomla.editors && Joomla.editors.instances && Joomla.editors.instances.hasOwnProperty("jform_send_body")){
										Joomla.editors.instances.jform_send_body.setValue(response.data.send_body);
									}
								});
							}
						});
						
						$("#es-send-link").on("click", function(e){
							e.preventDefault();							
							if($("#es-email-modal form").find("input, select, textarea").es_validate()){
								$("#es-email-modal form").submit();
							}
						});					
						
					});
				');
			}
		}

		JToolbarHelper::cancel('order.cancel', 'JTOOLBAR_CLOSE');
	}

	protected function beforeDisplay()
	{
		$paymentId   = (int) $this->item->payment_id;
		$this->order = easyshop('class.order');
		$this->order->load($this->item->id);

		if ($paymentId > 0)
		{
			/** @var $methodClass \ES\Method */
			$methodClass = easyshop('class.method');

			if ($payment = $methodClass->get($paymentId))
			{
				JPluginHelper::importPlugin('easyshoppayment', $payment->element);
				$this->payment         = clone $payment;
				$registry              = new Registry($this->item->payment_data);
				$this->payment->data   = $registry;
				$registry              = new Registry($this->payment->params);
				$this->payment->params = $registry;
				easyshop('app')->triggerEvent('onEasyshoppaymentOrderArea', [$this->order, $this->payment]);
			}
		}
	}
}
