<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

JLoader::register('EasyshopHelperRoute', ES_COMPONENT_SITE . '/helpers/route.php');

class ModEasyshopProductsHelper
{
	protected static $categories = [];

	public static function getItems($params)
	{
		/** @var $productClass \ES\Product */
		$productClass = easyshop('class.product');
		$mode         = $params->get('product_mode');
		$pks          = (array) $params->get($mode, []);
		$items        = [];

		if (empty($pks))
		{
			return $items;
		}

		if ($mode == 'products')
		{
			foreach ($pks as $pk)
			{
				$items[] = $productClass->getItem($pk, false, true);
			}
		}
		else
		{
			$db            = easyshop('db');
			$query         = $db->getQuery(true)
				->select('a.id')
				->from($db->qn('#__easyshop_products', 'a'))
				->leftJoin($db->qn('#__categories', 'a2') . ' ON a2.id = a.category_id');
			$where         = 'a.state = 1';
			$subCategories = $params->get('product_in_sub_categories');
			$limit         = (int) $params->get('limit', 8);

			/** @var \ES\Utility $utility */
			$utility = easyshop('class.utility');
			$utility->parseOrderingData(strtolower($params->get('sort_by')), $ordering, $direction);
			$query->order($ordering . ' ' . $direction);

			if (JLanguageMultilang::isEnabled())
			{
				$where .= ' AND a.language IN (' . $db->q('*') . ',' . $db->q(JFactory::getLanguage()->getTag()) . ')';
			}

			foreach ($pks as $pk)
			{
				$query->clear('where')
					->where($where);

				if ($subCategories)
				{
					$subQuery = $db->getQuery(true)
						->select('sub.id')
						->from($db->qn('#__categories', 'sub'))
						->innerJoin($db->qn('#__categories', 'this') . ' ON sub.lft > this.lft AND sub.rgt < this.rgt')
						->where('this.id = ' . (int) $pk);
					$query->where('(a.category_id = ' . (int) $pk . ' OR a.category_id IN (' . (string) $subQuery . '))');
				}
				else
				{
					$query->where('a.category_id = ' . (int) $pk);
				}

				$db->setQuery($query, 0, $limit);

				if ($ids = $db->loadColumn())
				{
					if ($category = JCategories::getInstance('easyshop.product')->get($pk))
					{
						self::$categories[$pk] = $category;
					}
					else
					{
						continue;
					}

					foreach ($ids as $id)
					{
						$items[$pk][] = $productClass->getItem($id, false, true);
					}
				}
			}
		}

		return $items;
	}

	public static function getCategories()
	{
		return self::$categories;
	}
}
