<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

defined('_JEXEC') or die;

class Button
{
	protected static $buttons = [];

	/**
	 * @param integer      $productId product ID
	 * @param string|array $html      button html output
	 * @param boolean      $prepend   Prepend
	 *
	 * @since 1.1.4
	 * @return \ES\Button
	 */

	public function addButton($productId, $html, $prepend = false)
	{
		$productId = (int) $productId;
		settype($html, 'array');

		foreach ($html as $button)
		{
			if ($prepend)
			{
				array_unshift(self::$buttons[$productId], $button);
			}
			else
			{
				self::$buttons[$productId][] = $button;
			}
		}

		return $this;
	}

	public function prependButton($productId, $html)
	{
		return $this->addButton($productId, $html, true);
	}

	public function getButtons($productId)
	{
		$productId = (int) $productId;

		return isset(self::$buttons[$productId]) ? self::$buttons[$productId] : false;
	}

	public function render($productId, $layoutId = 'product.button.default', $renderer = null)
	{
		$productId = (int) $productId;

		if (empty(self::$buttons[$productId]))
		{
			return '';
		}

		if (!($renderer instanceof LayoutHelper))
		{
			$renderer = easyshop('renderer');
		}

		return $renderer->render($layoutId, [
			'buttons' => self::$buttons[$productId],
		]);
	}
}
