<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

defined('_JEXEC') or die;

class Html
{
	protected $includePaths = [];

	public function __construct($config = [])
	{
		$template           = easyshop('app')->getTemplate();
		$this->includePaths = [
			JPATH_THEMES . '/' . $template . '/html/com_easyshop',
			JPATH_THEMES . '/' . $template,
		];

		// @since 1.1.6 optional load framework
		if (!empty($config['framework']))
		{
			\JHtml::_('easyshop.framework');
		}
	}

	public function addPath($paths)
	{
		settype($paths, 'array');

		foreach ($paths as $path)
		{
			$path = \JPath::clean($path);

			if (!in_array($path, $this->includePaths))
			{
				$this->includePaths[] = $path;
			}
		}

		return $this;
	}

	protected function addMedia($file, $type, $version = null)
	{
		static $mediaList = [];

		if (!in_array($file, $mediaList))
		{
			$mediaList[]  = $file;
			$includePaths = array_merge($this->includePaths, [ES_MEDIA]);

			if ($file = \JPath::find($includePaths, $type . '/' . $file))
			{
				$file     = \JPath::clean($file, '/');
				$file     = str_replace(\JPath::clean(JPATH_ROOT, '/'), \JUri::root(true), $file);
				$callBack = $type === 'js' ? 'addScript' : 'addStylesheet';
				call_user_func_array([easyshop('doc'), $callBack], [$file, ['version' => $version ? $version : null]]);
			}
		}

		return $this;
	}

	public function addCss($file, $version = null)
	{
		return $this->addMedia($file, 'css', $version);
	}

	public function addJs($file, $version = null)
	{
		return $this->addMedia($file, 'js', $version);
	}

	/**
	 * @param array $ui
	 *
	 * @since 1.1.0
	 * @return \ES\Html
	 */
	public function jui(array $ui = [])
	{
		\JHtml::_('jquery.ui', ['core']);

		if ($ui)
		{
			$doc        = easyshop('doc');
			$datePicker = in_array('datepicker', $ui);
			$timePicker = in_array('timepicker-addon', $ui);

			foreach ($ui as $component)
			{
				$doc->addScript(ES_MEDIA_URL . '/js/ui/jquery.ui.' . $component . '.min.js');
			}

			if ($datePicker || $timePicker)
			{
				$appendJs = PHP_EOL . 'var dateTimeOpts = ' . json_encode([
						'closeText'          => \JText::_('COM_EASYSHOP_UI_DATETIME_CLOSETEXT'),
						'prevText'           => \JText::_('COM_EASYSHOP_UI_DATETIME_PREVTEXT'),
						'nextText'           => \JText::_('COM_EASYSHOP_UI_DATETIME_NEXTTEXT'),
						'currentText'        => \JText::_('COM_EASYSHOP_UI_DATETIME_CURRENTTEXT'),
						'monthNames'         => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_MONTHSNAME'))),
						'monthNamesShort'    => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_MONTHSNAMESHORT'))),
						'dayNames'           => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_DAYNAMES'))),
						'dayNamesShort'      => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_DAYNAMESSHORT'))),
						'dayNamesMin'        => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_DAYNAMESMIN'))),
						'weekHeader'         => \JText::_('COM_EASYSHOP_UI_DATETIME_WEEKHEADER'),
						'dateFormat'         => \JText::_('COM_EASYSHOP_UI_DATETIME_DATEFORMAT'),
						'firstDay'           => (int) \JText::_('COM_EASYSHOP_UI_DATETIME_FIRSTDAY'),
						'isRTL'              => $doc->direction === 'rtl',
						'showMonthAfterYear' => in_array(strtolower(\JText::_('COM_EASYSHOP_UI_DATETIME_SHOWMONTHAFTERYEAR')), ['1', 'true', 'yes'], true),
						'yearSuffix'         => \JText::_('COM_EASYSHOP_UI_DATETIME_YEARSUFFIX'),
						'amNames'            => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_AMNAMES'))),
						'pmNames'            => array_map('trim', explode(',', \JText::_('COM_EASYSHOP_UI_DATETIME_PMNAMES'))),
						'timeFormat'         => \JText::_('COM_EASYSHOP_UI_DATETIME_TIMEFORMAT'),
						'timeSuffix'         => \JText::_('COM_EASYSHOP_UI_DATETIME_TIMESUFFIX'),
						'timeOnlyTitle'      => \JText::_('COM_EASYSHOP_UI_DATETIME_TIMEONLYTITLE'),
						'timeText'           => \JText::_('COM_EASYSHOP_UI_DATETIME_TIMETEXT'),
						'hourText'           => \JText::_('COM_EASYSHOP_UI_DATETIME_HOURTEXT'),
						'minuteText'         => \JText::_('COM_EASYSHOP_UI_DATETIME_MINUTETEXT'),
						'secondText'         => \JText::_('COM_EASYSHOP_UI_DATETIME_SECONDTEXT'),
						'millisecText'       => \JText::_('COM_EASYSHOP_UI_DATETIME_MILLISECTEXT'),
						'microsecText'       => \JText::_('COM_EASYSHOP_UI_DATETIME_MICROSECTEXT'),
						'timezoneText'       => \JText::_('COM_EASYSHOP_UI_DATETIME_TIMEZONETEXT'),
					]) . ';';

				if ($datePicker)
				{
					$appendJs .= PHP_EOL . '_es.$.datepicker.setDefaults(dateTimeOpts);';
				}

				if ($timePicker)
				{
					$appendJs .= PHP_EOL . '_es.$.timepicker.setDefaults(dateTimeOpts);';
				}

				$doc->addScriptDeclaration($appendJs);
			}
		}

		return $this;
	}

	/**
	 * Init chosen library
	 * @since 1.1.3
	 */
	public function initChosen()
	{
		static $chosen = false;

		if (!$chosen)
		{
			\JHtml::_('script', 'jui/chosen.jquery.min.js', ['version' => 'auto', 'relative' => true]);
			\JHtml::_('stylesheet', 'jui/chosen.css', ['version' => 'auto', 'relative' => true]);
			$chosen = true;

			easyshop('doc')->addScriptDeclaration('
				jQuery(function ($) {
					_es.initChosen = function(container) {
						var select,
							options = {
							disable_search_threshold: 10,
							search_contains: true,
							allow_single_deselect: true,
							placeholder_text_multiple: "' . \JText::_('JGLOBAL_TYPE_OR_SELECT_SOME_OPTIONS') . '",
							placeholder_text_single: "' . \JText::_('JGLOBAL_SELECT_AN_OPTION') . '",
							no_results_text: "' . \JText::_('JGLOBAL_SELECT_NO_RESULTS_MATCH') . '"						
						}, list;
						
						if (container){
							list = $(container).find("select");
						} else {
						    list = $(document).find(".es-scope select");
						}
						
						list.each(function(){
							select = $(this);	
							select.chosen("destroy");
													
							if (select.find("option").length > 10 && !select.hasClass("not-chosen")){
								select.chosen(options);
							}						
						});
					};
					
					_es.initChosen();
					$("body").on("subform-row-add", _es.initChosen);
				});
			');
		}

		return $this;
	}

	public function initDateTimePicker()
	{
		static $done = false;

		if (!$done)
		{
			$done = true;
			$this->jui(['datepicker', 'slider', 'timepicker-addon'])
				->addCss('ui/ui.css');
			easyshop('doc')->addScriptDeclaration(<<<JAVASCRIPT
				_es.$(document).ready(function ($) {		
					var body = $('body');			
					body.on('click', function (e) {
						var target = $(e.target);
						
						if (!target.parents('.es-field-datetime-picker-container').length 
							&& !target.hasClass('ui-datepicker-current')
						) {
							$('.es-datetime-picker-container:not(.es-datetime-picker-inline)').prop('hidden', true);
						}
						
					});
					
					body.on('focus blur', 'textarea, select, input', function () {
						if (!$(this).parents('.es-field-datetime-picker-container').length) {
							$('.es-datetime-picker-container:not(.es-datetime-picker-inline)').prop('hidden', true);
						}
					});
				});
JAVASCRIPT
			);
		}
	}
}
