<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

class LayoutHelper
{
	protected $includePaths = [];
	protected $basePath;

	public function __construct($config)
	{
		if (!empty($config['basePath']))
		{
			$this->basePath = $config['basePath'];
		}
		else
		{
			$this->basePath = ES_COMPONENT . '/layouts';
		}
	}

	public function render($layoutId, $displayData = [])
	{
		$option = new Registry;
		$option->set('component', 'none');
		$layout = new \JLayoutFile($layoutId, $this->basePath, $option);

		if (count($this->includePaths))
		{
			$layout->addIncludePath($this->includePaths);
		}

		if (is_array($displayData) && !array_key_exists('renderer', $displayData))
		{
			$displayData['renderer'] = $this;
		}
		elseif (is_object($displayData) && !property_exists($displayData, 'renderer'))
		{
			$displayData->renderer = $this;
		}

		if (is_array($displayData) && !array_key_exists('factory', $displayData))
		{
			$displayData['factory'] = Factory::getInstance();
		}
		elseif (is_object($displayData) && !property_exists($displayData, 'factory'))
		{
			$displayData->factory = Factory::getInstance();
		}

		if (is_array($displayData) && !array_key_exists('currency', $displayData))
		{
			$displayData['currency'] = easyshop('class.currency')->getActive();
		}
		elseif (is_object($displayData) && !property_exists($displayData, 'currency'))
		{
			$displayData->currency = easyshop('class.currency')->getActive();
		}

		return $layout->render($displayData);
	}

	public function getSiteTemplate()
	{
		static $siteTemplate = null;

		if (null === $siteTemplate)
		{
			$db    = \JFactory::getDbo();
			$query = $db->getQuery(true)
				->select('a.template')
				->from($db->qn('#__template_styles', 'a'))
				->where('a.home = 1 AND a.client_id = 0');
			$db->setQuery($query);
			$siteTemplate = $db->loadResult();
		}

		return $siteTemplate;
	}

	public function setPaths($paths, $resetPath = true)
	{
		settype($paths, 'array');

		if ($resetPath)
		{
			$this->includePaths = [];
		}

		return $this->addIncludePath($paths);
	}

	public function refreshDefaultPaths($tplName = 'default')
	{
		$this->basePath = ES_COMPONENT . '/layouts';
		$tplPath        = JPATH_THEMES . '/' . easyshop('app')->getTemplate() . '/html/com_easyshop/layouts';
		$this->setPaths([
			$tplPath . '/' . $tplName,
			$tplPath,
			ES_COMPONENT_ADMINISTRATOR . '/layouts',
		]);

		return $this;
	}

	public function addIncludePath($paths)
	{
		settype($paths, 'array');

		foreach ($paths as $path)
		{
			if (is_dir($path))
			{
				$this->includePaths[] = \JPath::clean($path, '/');
			}
		}

		return $this->includePaths;
	}

}
