<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

defined('_JEXEC') or die;

use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Factory;

class Method
{
	protected static $shippingMethods = [];
	protected static $paymentMethods = [];

	public function load()
	{
		static $items = null;

		if (null === $items)
		{
			$items = [];
			$db    = easyshop('db');
			$query = $db->getQuery(true)
				->select('a.id, a.name, a.show_name, a.plugin_id, a.image, a.description, a.description_type, a.flat_fee, a.percentage_fee, a.params, e.element, e.folder AS plugin_group, a.is_default, a.order_status')
				->from($db->qn('#__easyshop_methods', 'a'))
				->innerJoin($db->qn('#__extensions', 'e') . ' ON a.plugin_id = e.extension_id')
				->where('a.state = 1 AND e.enabled = 1 AND e.type = ' . $db->q('plugin'))
				->where('e.folder IN (' . $db->q('easyshop') . ',' . $db->q('easyshoppayment') . ',' . $db->q('easyshopshipping') . ')')
				->order('a.ordering ASC');

			if (Multilanguage::isEnabled())
			{
				$query->where('a.language in (' . $db->q(Factory::getLanguage()->getTag()) . ',' . $db->q('*') . ')');
			}

			easyshop('app')->triggerEvent('onEasyshopPrepareListQuery', ['com_easyshop.methods', $query]);
			$db->setQuery($query);

			if ($methods = $db->loadObjectList('id'))
			{
				$items = $methods;
			}
		}

		return $items;
	}

	public function getGroup($groupName)
	{
		static $groups = [];

		if (!isset($groups[$groupName]))
		{
			$groups[$groupName] = [];

			foreach ($this->load() as $id => $method)
			{
				if ($method->plugin_group == $groupName)
				{
					$groups[$groupName][$id] = $method;
				}
			}
		}

		return $groups[$groupName];
	}

	public function get($pk = 0)
	{
		$methods = $this->load();

		return isset($methods[$pk]) ? $methods[$pk] : false;
	}

	protected function addMethod($class = null, $type)
	{
		if ($class instanceof \stdClass)
		{
			if ($type == 'shipping')
			{
				static::$shippingMethods[$class->id] = $class;
			}
			else
			{
				static::$paymentMethods[$class->id] = $class;
			}
		}

		return $type == 'shipping' ? static::$shippingMethods : static::$paymentMethods;
	}

	public function getPaymentMethods()
	{
		return $this->getGroup('easyshoppayment');
	}

	public function getShippingMethods()
	{
		return $this->getGroup('easyshopshipping');
	}

	public function addShippingMethod($class = null)
	{
		return static::addMethod($class, 'shipping');
	}

	public function addPaymentMethod($class = null)
	{
		return static::addMethod($class, 'payment');
	}
}
