<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;

defined('_JEXEC') or die;

\JLoader::register('EasyshopHelperRoute', ES_COMPONENT_SITE . '/helpers/route.php');

class Product
{
	public function getTable()
	{
		static $table = null;

		if (null === $table)
		{
			\JTable::addIncludePath(ES_COMPONENT_ADMINISTRATOR . '/tables');
			$table = \JTable::getInstance('Product', 'EasyshopTable');
		}

		return $table;
	}

	public function getItem($pk, $reload = false, $prepare = true)
	{
		static $products = [];
		$pk = (int) $pk;

		if (!isset($products[$pk]) || $reload)
		{
			/**
			 * @var $currency          \ES\Currency
			 * @var $cart              \ES\Cart
			 * @var $discountClass     \ES\Discount
			 * @var $product           \stdClass
			 * @var $app               \JApplicationCms
			 */

			$app   = easyshop('app');
			$table = $this->getTable();

			if ($pk < 1 || !$table->load($pk))
			{
				$app->enqueueMessage(\JText::sprintf('COM_EASYSHOP_PRODUCT_NOT_FOUND', $pk));

				return false;
			}

			$product              = ArrayHelper::toObject($table->getProperties());
			$product->params      = new Registry($product->params);
			$product->images      = $this->getImages($pk);
			$product->prices      = $this->getPrices($pk);
			$product->productTags = $this->getTags($pk);
			$product->taxes       = $this->getTaxes($product->taxes);
			$product->retailPrice = $product->price;
			$unit                 = $product->dimension_unit;
			$product->dimension   = $product->length . $unit . ' x ' . $product->width . $unit . ' x ' . $product->height . $unit;

			if (empty($product->option_fields))
			{
				$product->option_fields = '{}';
			}

			$registry = new Registry;
			$registry->loadString((string) $product->option_fields);
			$product->option_fields      = $registry->toArray();
			$product->extraDetailDisplay = [];
			$product->extraBlockDisplay  = [];
			// Category
			$product->category = \JCategories::getInstance('easyshop.product')->get($product->category_id);

			if (easyshop('site'))
			{
				$product->category->link = \JRoute::_(\EasyshopHelperRoute::getCategoryRoute($product->category, $product->category->language), false);
				$currency                = easyshop('class.currency')->getActive();
				$product->discount       = 0.00;

				if (!empty($product->productTags))
				{
					easyshop('prepare.tag', $product->productTags);
				}

				// Brand
				if ($product->brand_id)
				{
					$product->brand       = \JCategories::getInstance('easyshop.brand')->get($product->brand_id);
					$product->brand->link = \JRoute::_(\EasyshopHelperRoute::getSearchRoute(['task' => 'search', 'brand' => $product->brand_id], $product->brand->language), false);
				}

				$product->salePrice = $product->price;
				$product->currency  = $currency->get('code');
				$discountClass      = easyshop('class.discount');
				$discountClass->applyOnProduct($product);
				$product->totalTaxes = $this->getTotalTaxes($product, $product->salePrice);
				$product->saleTaxes  = $product->totalTaxes;
				$cartItems           = easyshop('class.cart')->getItems();
				$product->cart       = [
					'quantity' => 1,
					'options'  => [],
				];

				if (isset($cartItems[$pk]))
				{
					$cartItem = array_pop($cartItems[$pk]);

					if (!empty($cartItem))
					{
						unset($cartItem['product']);
						$product->cart        = $cartItem;
						$product->salePrice   = $cartItem['price'];
						$product->saleTaxes   = $cartItem['taxes'];
						$product->taxesFormat = $currency->toFormat($product->saleTaxes, true);
					}
				}

				if (!isset($product->taxesFormat))
				{
					$product->taxesFormat = $currency->toFormat($product->totalTaxes, true);
				}

				if (easyshop('config', 'zero_as_free', 0) && (float) $product->salePrice < 0.01)
				{
					$product->priceFormat = \JText::_('COM_EASYSHOP_FREE_PRODUCT');
				}
				else
				{
					$product->priceFormat = $currency->toFormat($product->salePrice, true);
				}

				$this->loadCustomFields($product);
				$this->loadOptions($product);

				// Route
				$link          = \EasyshopHelperRoute::getProductRoute($product->id, $product->category_id, $product->language);
				$product->link = \JRoute::_($link, false);

				// Params inherit
				$config = easyshop('config');

				foreach ($product->params->toArray() as $name => $value)
				{
					if (trim($value) === '' && $config->exists($name))
					{
						$product->params->set($name, $config->get($name));
					}
				}

				// Max quantity and stock
				$maxQuantity = (int) $product->params->get('product_detail_max_quantity', 0);
				$stock       = (int) $product->stock;

				if ($maxQuantity < 1)
				{
					$maxQuantity = (int) $config->get('product_detail_max_quantity', 0);
				}

				if ($stock !== -1)
				{
					if ($stock < 1)
					{
						$product->params->set('product_detail_add_to_cart', 0);
					}

					$maxQuantity = $stock;
				}

				$product->params->set('product_detail_max_quantity', $maxQuantity);

				// @since 1.1.6
				$product->extraBlockFlexDisplay  = [];
				$product->extraDetailFlexDisplay = [];

				if ($prepare)
				{
					$app->triggerEvent('onEasyshopProductPrepare', [$product]);
				}

				// @since 1.1.0
				$nullDate            = easyshop('db')->getNullDate();
				$product->expireDate = false;

				if (!empty($product->sale_from_date)
					&& $product->sale_from_date != $nullDate
					&& !empty($product->sale_to_date)
					&& $product->sale_to_date != $nullDate
				)
				{
					$nowDate    = \JFactory::getDate();
					$date1      = \JFactory::getDate($product->sale_from_date);
					$date2      = \JFactory::getDate($product->sale_to_date);
					$stringDate = strtotime($nowDate->format('Y-m-d H:i:s'));

					if ($stringDate >= strtotime($date1->format('Y-m-d H:i:s'))
						&& $stringDate < strtotime($date2->format('Y-m-d H:i:s'))
					)
					{
						$product->expireDate = easyshop('class.utility')->getDate($product->sale_to_date);
					}
					else
					{
						$product->expireDate = true;
						$product->params->set('product_detail_add_to_cart', 0);
					}
				}
			}
			elseif ($prepare)
			{
				$app->triggerEvent('onEasyshopAdminProductPrepare', [$product]);
			}

			$products[$pk] = $product;
		}

		return $products[$pk];
	}

	protected function loadCustomFields($product)
	{
		/**
		 * @var $customField  \ES\CustomField
		 * @var $layoutHelper \ES\LayoutHelper
		 */
		$customField  = easyshop('class.customfield', [
			'reflector'    => 'com_easyshop.product.customfield',
			'reflector_id' => $product->id,
		]);
		$layoutHelper = easyshop('class.layoutHelper');
		$layoutHelper->refreshDefaultPaths();
		$product->customfields = [];

		foreach ($customField->getGroups() as $group)
		{
			$params  = new Registry((string) $group->params);
			$assigns = (array) $params->get('product_categories', []);

			if (empty($assigns) || in_array($product->category_id, $assigns))
			{
				$fields           = (array) $group;
				$fields['params'] = $params;
				$fields['fields'] = $customField->getItemsByGroup($fields['id'], $product->id);
				$search           = '{fields}' . $fields['alias'] . '{/fields}';

				if (stripos($product->description, $search) !== false)
				{
					$replace              = $layoutHelper->render('product.field.' . $params->get('fields_output_layout', 'table'), [
						'fields' => $fields['fields'],
					]);
					$product->description = str_ireplace($search, $replace, $product->description);
				}
				else
				{
					$product->customfields[] = $fields;
				}
			}
		}
	}

	public function loadOptions($product, $layoutId = 'product.option')
	{
		// Options
		$product->options = '';

		/**
		 * @var $optionField  \ES\CustomField
		 * @var $layoutHelper \ES\LayoutHelper
		 */

		$optionField = easyshop('class.customfield', [
			'reflector'    => 'com_easyshop.product.option',
			'reflector_id' => $product->id,
		]);
		$currency    = easyshop('class.currency')->getActive();
		$xml         = new \DOMDocument('1.0', 'UTF-8');
		$form        = $xml->appendChild(new \DOMElement('form'));
		$fieldSet    = $form->appendChild(new \DOMElement('fieldset'));
		$fieldSet->setAttribute('name', 'option');
		$options = [];

		foreach ($optionField->load() as $groupId => $items)
		{
			$options += $items;
		}

		easyshop('prepare.customfield', $options);

		foreach ($product->option_fields as $fieldId => $fieldValue)
		{
			if (isset($options[$fieldId]))
			{
				// Fix pointer
				$option              = (array) $options[$fieldId];
				$type                = strtolower($option['type']);
				$fieldValue['value'] = @json_decode($fieldValue['value'], true);

				if (!empty($fieldValue['options'])
					&& !empty($fieldValue['value'])
					&& in_array($type, ['list', 'radio', 'colors', 'inline'])
				)
				{
					$params                = new Registry($option['params']);
					$optionParams          = $params->get('options', []);
					$fieldValue['options'] = array_map(function ($opt) {
						return $opt['value'];
					}, $fieldValue['options']);
					$newOptions            = [];

					foreach ($optionParams as $optionParam)					{

						if (isset($optionParam->value)
							&& isset($fieldValue['value'][$optionParam->value])
							&& $fieldValue['value'][$optionParam->value] === 'disabled'
						)
						{
							continue;
						}

						if (in_array($optionParam->value, $fieldValue['options']))
						{
							$newOptions[] = $optionParam;
						}
					}

					if (empty($newOptions))
					{
						continue;
					}

					$params->set('options', $newOptions);
					$option['params'] = (string) $params->toString();
				}

				$optionField->prepareField($fieldSet, (object) $option, $fieldId);
			}
		}

		\JForm::addFieldPath(ES_COMPONENT_ADMINISTRATOR . '/models/fields');
		$form     = \JForm::getInstance('com_easyshop.option.' . $product->id, $xml->saveXML(), ['control' => 'product_option']);
		$renderer = easyshop('renderer');

		foreach ($form->getFieldset('option') as $field)
		{
			$name   = $field->getAttribute('name');
			$value  = $field->getAttribute('default');
			$prefix = '';

			if (isset($product->cart['options'][$name]['value']))
			{
				$value  = $product->cart['options'][$name]['value'];
				$prefix = (float) $product->cart['options'][$name]['prefix'];

				if ($prefix > 0.00 || $prefix < 0.00)
				{
					if ($prefix > 0.00)
					{
						$prefix = '+' . $currency->toFormat(abs($prefix), true);
					}
					else
					{
						$prefix = '-' . $currency->toFormat(abs($prefix), true);
					}
				}
				else
				{
					$prefix = '';
				}
			}

			$field->__set('id', $name . '_' . $product->id);
			$field->__set('value', $value);
			$input = $renderer->render($layoutId, [
				'field'  => $field,
				'prefix' => $prefix,
			]);

			if (strcasecmp($field->getAttribute('type'), 'checkbox') === 0 && empty($value))
			{
				$input = str_replace('checked', '', $input);
			}

			$product->options .= $input;
		}
	}

	public function getTotalTaxes($product, $retailPrice = null)
	{
		$taxesAmount = 0.00;

		if (count($product->taxes))
		{
			if (null === $retailPrice)
			{
				$retailPrice = (float) $product->price;
			}

			foreach ($product->taxes as $tax)
			{
				if ((int) $tax->type)
				{
					$rate        = (float) $tax->rate;
					$taxesAmount += (($retailPrice * $rate) / 100);
				}
				else
				{
					$taxesAmount += (float) $tax->flat;
				}
			}
		}

		return $taxesAmount;
	}

	public function isEnabled($productId = 0, $checkIsSale = true)
	{
		$db    = easyshop('db');
		$query = $db->getQuery(true)
			->select('COUNT(a.id)')
			->from($db->qn('#__easyshop_products', 'a'))
			->where('a.state = 1 AND a.id = ' . (int) $productId);

		if ($checkIsSale)
		{
			$nullDate = $db->q($db->getNullDate());
			$now      = $db->q(\JFactory::getDate()->toSql());
			$query->where('
				CASE WHEN 
					a.sale_from_date <> ' . $nullDate . ' AND a.sale_to_date <> ' . $nullDate
				. ' THEN ' . $now . ' BETWEEN a.sale_from_date AND a.sale_to_date'
				. ' ELSE 1 END
				');
		}

		$db->setQuery($query);

		return $db->loadResult();
	}

	public function getPrices($productId = 0)
	{
		$db    = easyshop('db');
		$query = $db->getQuery(true);
		$query->select('p.price_value, p.currency_id, p.min_quantity')
			->from($db->qn('#__easyshop_prices', 'p'))
			->order('p.min_quantity')
			->where('p.product_id = ' . (int) $productId);
		$db->setQuery($query);

		if ($prices = $db->loadObjectList())
		{
			return $prices;
		}

		return [];
	}

	public function getImages($productId = 0)
	{
		$db    = easyshop('db');
		$query = $db->getQuery(true)
			->select('a.file_path, a.title, a.description, a.ordering')
			->from($db->qn('#__easyshop_medias', 'a'))
			->where('a.type = ' . $db->q('IMAGE') . ' AND a.product_id = ' . (int) $productId)
			->order('a.ordering ASC');
		$db->setQuery($query);

		if ($images = $db->loadObjectList())
		{
			/** @var \ES\Media $mediaClass */
			$mediaClass = easyshop('class.media');

			foreach ($images as &$image)
			{
				foreach ($mediaClass->getFullImages($image->file_path) as $size => $src)
				{
					$image->{$size} = $src;
				}
			}
		}

		return $images;
	}

	public function getTags($productId)
	{
		return easyshop('class.tags')->getProductTags($productId);
	}

	public function getTaxes($taxes)
	{
		$taxes = explode('][', trim(preg_replace('/^\[|\]$/', '', $taxes)));

		if (count($taxes))
		{
			$taxes = ArrayHelper::toInteger($taxes);
			$db    = easyshop('db');
			$query = $db->getQuery(true)
				->select('t.id, t.name, t.flat, t.type, t.rate, t.vendor_id')
				->from($db->qn('#__easyshop_taxes', 't'))
				->where('t.id IN (' . join(',', $taxes) . ')');
			$db->setQuery($query);

			$taxes = $db->loadObjectList('id');
		}

		return $taxes;
	}
}
