<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;

defined('_JEXEC') or die;

class System
{
	/**
	 * Fix install database schema: Add missed columns, correct the type of columns and ADD TABLE IF NOT EXISTS
	 * @since 1.1.5
	 * @return boolean
	 */
	public function fixSchemas()
	{
		$app = easyshop('app');

		try
		{
			$queries = [];

			if ($contents = file_get_contents(ES_COMPONENT_ADMINISTRATOR . '/sql/mysql/install.sql'))
			{
				/** @var \JDatabaseDriver $db */
				$db        = easyshop('db');
				$tableList = $db->getTableList();
				$prefix    = $db->getPrefix();
				$types     = join('|', [
					'INT',
					'TINYINT',
					'SMALLINT',
					'MEDIUMINT',
					'BIGINT',
					'FLOAT',
					'DOUBLE',
					'DECIMAL',
					'DATETIME',
					'DATE',
					'TIMESTAMP',
					'TIME',
					'YEAR',
					'CHAR',
					'VARCHAR',
					'BLOB',
					'TEXT',
					'TINYBLOB',
					'TINYTEXT',
					'MEDIUMBLOB',
					'MEDIUMTEXT',
					'LONGBLOB',
					'LONGTEXT',
					'ENUM',
				]);

				foreach ($db->splitSql($contents) as $content)
				{
					preg_match('/CREATE TABLE IF NOT EXISTS \`(#[_a-zA-Z0-9]+)\`/i', $content, $matches);

					if (!empty($matches[1]))
					{
						$originTable = $db->qn($matches[1]);
						$table       = str_replace('#__', $prefix, $matches[1]);

						if (!in_array($table, $tableList))
						{
							// Create table
							$queries[] = $matches[0] . '...';
							$db->setQuery($content)
								->execute();
							continue;
						}

						$columns   = $db->getTableColumns($table, true);
						$fields    = array_keys($columns);
						$lastField = $db->qn($fields[count($fields) - 1]);
						$lines     = preg_split('/\n|\r\n/', $content);

						foreach ($lines as $line)
						{
							preg_match('/^\`([a-z0-9_]+)\`\s+(' . $types . ').+\,$/i', trim($line), $matches);

							if ($matches)
							{
								list($queryString, $field, $type) = array_map('trim', $matches);
								$queryString = preg_replace('/\,$/', '', $queryString);
								$fieldName   = $db->qn($field);

								if (isset($columns[$field]))
								{
									if (stripos($columns[$field], $type) !== 0)
									{
										// Change column
										$query     = str_replace($fieldName, 'ALTER TABLE ' . $originTable . ' CHANGE COLUMN ' . $fieldName . ' ' . $fieldName, $queryString);
										$queries[] = $query;
										$db->setQuery($query)
											->execute();
									}
								}
								else
								{
									// Add new column
									$query     = str_replace($fieldName, 'ALTER TABLE ' . $originTable . ' ADD COLUMN ' . $fieldName, $queryString) . ' AFTER ' . $lastField;
									$queries[] = $query;
									$db->setQuery($query)
										->execute();
								}
							}
						}
					}
				}

				if ($queries)
				{
					$app->enqueueMessage('<h5>' . sprintf('%02d', count($queries)) . ' queries executed</h5><ol><li>' . join('</li><li>', $queries) . '</li></ol>');
				}
				else
				{
					$app->enqueueMessage('No queries executed.');
				}

				return true;
			}
		}
		catch (\RuntimeException $e)
		{
			$app->enqueueMessage($e->getMessage(), 'error');
		}

		return false;
	}
}
