<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES;
defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;
use ES\Controller\ControllerLegacy;

class Factory
{
	/**
	 * @var \JApplicationCms
	 * @since 1.0.0
	 */
	protected $app;

	/**
	 * @var \JDocument
	 * @since 1.0.0
	 */
	protected $doc;

	/**
	 * @var \JDatabaseDriver
	 * @since 1.0.0
	 */
	protected $db;
	/**
	 * @var  $state \Joomla\Registry\Registry
	 * @since 1.0.0
	 */
	protected $state;
	protected static $classPaths = [];
	protected static $classes = [];
	protected static $instance = null;

	public static function getInstance()
	{
		if (null === self::$instance)
		{
			self::$instance = new Factory;
		}

		return self::$instance;
	}

	public function dispatch()
	{
		if (easyshop('administrator')
			&& !easyshop('class.user')->core('manage', 'com_easyshop')
		)
		{
			throw new \Exception(\JText::_('JERROR_ALERTNOAUTHOR'), 403);
		}

		$this->addLangText([
			'COM_EASYSHOP_INPUT_INVALID_REQUIRED',
			'COM_EASYSHOP_INPUT_INVALID_MIN',
			'COM_EASYSHOP_INPUT_INVALID_MAX',
			'COM_EASYSHOP_INPUT_INVALID_REGEX',
			'COM_EASYSHOP_INPUT_INVALID_EMAIL',
			'COM_EASYSHOP_INPUT_INVALID_NUMBER',
		]);

		\JPluginHelper::importPlugin('easyshop');
		\JLoader::import('easyshop.controller.legacy');
		\JHtml::_('ukui.tabState');
		easyshop('class.html')->initChosen();

		$config = [];
		$user   = $this->getClass('User');
		$view   = $this->app->input->get('view');
		$task   = $this->app->input->get('task');

		if ($user->load() && ($view == 'media' || strpos($task, 'media.') === 0))
		{
			$config['base_path'] = ES_COMPONENT_ADMINISTRATOR;
		}

		$this->app->triggerEvent('onEasyshopBeforeDispatch', [&$config]);
		ob_start();
		$controller = ControllerLegacy::getInstance('Easyshop', $config);
		$controller->execute($this->app->input->getCmd('task'));
		$buffer = ob_get_clean();
		$this->app->triggerEvent('onEasyshopAfterDispatch', [&$buffer]);
		echo '<div id="es-component" class="uk-scope es-scope">' . $buffer . '</div>';

		$controller->redirect();
	}

	public function addLangText($keys = [])
	{
		settype($keys, 'array');
		$data = [];

		foreach ($keys as $key)
		{
			$key        = trim(strtoupper($key));
			$data[$key] = \JText::_($key);
		}

		$this->doc->addScriptDeclaration('
			_es.lang.load(' . json_encode($data) . ');
		');
	}

	public function getClass($className, $config = [], $namespace = 'ES', $constructor = '__construct')
	{
		$class     = '\\' . $namespace . '\\' . ucfirst($className);
		$className = strtolower($className);
		$classPath = null;

		if (isset(self::$classes[$className]))
		{
			list($classPath, $classAlias) = self::$classes[$className];

			if (null !== $classAlias)
			{
				$class = $classAlias;
			}
		}

		if (!class_exists($class))
		{
			if (null === $classPath)
			{
				$classPath = \JPath::find($this->addIncludeClassPath(), $className . '.php');
			}

			if (is_file($classPath))
			{
				require_once $classPath;
			}
		}

		if (!class_exists($class))
		{
			throw new \RuntimeException('Class \\' . $class . ' not found');
		}

		if ($constructor != '__construct' && is_callable([$class, $constructor]))
		{
			return call_user_func_array([$class, $constructor], [$config]);
		}

		return new $class($config);
	}

	public function getModel($name, $basePath = ES_COMPONENT, $config = ['ignore_request' => true])
	{
		static $includePaths = [];

		if (!in_array($basePath, $includePaths))
		{
			\JModelLegacy::addIncludePath($basePath . '/models', 'EasyshopModel');
			$includePaths[] = $basePath;
		}

		return \JModelLegacy::getInstance(ucfirst($name), 'EasyshopModel', $config);
	}

	public function addIncludeClassPath($paths = [])
	{
		settype($paths, 'array');

		foreach ($paths as $path)
		{
			$path = \JPath::clean($path);

			if (!in_array($path, self::$classPaths))
			{
				array_push(self::$classPaths, $path);
			}
		}

		return self::$classPaths;

	}

	public function getConfig($name = null, $default = null)
	{
		static $config;

		if (!($config instanceof Registry))
		{
			$config = clone \JComponentHelper::getParams('com_easyshop');

			if ($this->app->getName() == 'site')
			{
				$listLimit = $config->get('list_limit', '15,25,50,75,100');

				if (strpos($listLimit, ',') === false)
				{
					$listLimit = '15,25,50,75,100';
				}

				$listLimit = preg_replace('/\,+/', ',', trim($listLimit));
				$listLimit = ArrayHelper::toInteger(explode(',', $listLimit));
				$config->set('list_limit', $listLimit);
			}
		}

		return $name ? $config->get($name, $default) : $config;
	}

	public function getPlugin($name, $group = 'easyshop')
	{
		static $plugins = [];

		if (!isset($plugins[$name]))
		{
			$pluginTable = \JTable::getInstance('Extension', 'JTable');

			if (!$pluginTable->load([
				'folder'  => strtolower($group),
				'element' => strtolower($name),
				'type'    => 'plugin',
				'enabled' => '1',
			])
			)
			{
				return false;
			}

			$params         = new Registry($pluginTable->params);
			$plugin         = new Registry($pluginTable->getProperties());
			$plugin         = $plugin->toObject();
			$plugin->params = $params;
			$plugins[$name] = $plugin;
		}

		return $plugins[$name];
	}

	public function __get($name)
	{
		switch ($name)
		{
			case 'app':

				if (!isset($this->app))
				{
					$this->app = \JFactory::getApplication();
				}

				return $this->app;

			case 'db':

				if (!isset($this->db))
				{
					$this->db = \JFactory::getDbo();
				}

				return $this->db;

			case 'doc':

				if (!isset($this->doc))
				{
					$this->doc = \JFactory::getDocument();
				}

				return $this->doc;

			case 'state':

				if (!($this->state instanceof Registry))
				{
					$this->state = new Registry;
				}

				return $this->state;
		}

		throw new \RuntimeException('Cannot access protected property class \\ES\\Factory::' . $name);
	}

	public function registerClass($className, $classPath, $classAlias = null)
	{
		$className = strtolower($className);

		if (!isset(self::$classes[$className]) && is_file($classPath))
		{
			self::$classes[$className] = [$classPath, $classAlias];
		}

		return self::$classes;
	}
}
