<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES\View;

use ES\LayoutHelper;

defined('_JEXEC') or die;

class ViewLegacy extends \JViewLegacy
{
	/**
	 * @var $currency  \ES\Currency
	 * @var $config    \Joomla\Registry\Registry
	 * @var $utility   \ES\Utility
	 * @since 1.0.0
	 */
	protected $currency;
	protected $renderer = null;
	protected $config = null;
	protected $utility = null;

	public function __construct(array $config)
	{
		$viewName                = $this->getName();
		$templateName            = $this->getTemplateName();
		$styleName               = easyshop('app')->getTemplate();
		$reflection              = new \ReflectionClass($this);
		$basePath                = dirname($reflection->getFileName());
		$tplPath                 = dirname(dirname($basePath)) . '/templates';
		$config['template_path'] = [
			ES_COMPONENT_ADMINISTRATOR . '/templates/global',
			$basePath . '/tmpl',
			$tplPath . '/' . $templateName . '/' . $viewName,
			JPATH_THEMES . '/' . $styleName . '/html/com_easyshop/views/' . $viewName,
			JPATH_THEMES . '/' . $styleName . '/html/com_easyshop/' . $templateName . '/' . $viewName
		];
		$tClass                  = 'EasyshopTemplate' . ucfirst($templateName);
		$paths                   = [
			JPATH_THEMES . '/' . $styleName . '/html/com_easyshop/' . $templateName,
			$tplPath . '/' . $templateName,
			ES_COMPONENT_ADMINISTRATOR . '/templates/' . $templateName,
		];

		if (!class_exists($tClass) && ($file = \JPath::find($paths, 'template.php')))
		{
			require_once $file;

			$tObject = new $tClass($config, dirname($file) . '/' . $viewName);

			if (is_callable([$tObject, 'onLoad']))
			{
				call_user_func_array([$tObject, 'onLoad'], []);
			}
		}

		if (easyshop('app')->getName() == 'site')
		{
			$this->currency = easyshop('class.currency')->getActive();
		}
		else
		{
			$this->currency = easyshop('class.currency')->getDefault();
		}

		$this->utility = easyshop('class.utility');
		$this->config  = clone easyshop('config');
		parent::__construct($config);
	}

	public function getTemplateName()
	{
		return 'default';
	}

	/**
	 * @return \ES\LayoutHelper
	 * @since 1.0.0
	 */

	public function getRenderer()
	{
		if (null === $this->renderer)
		{
			$renderer = easyshop('state')->get('view.' . $this->getName() . '.renderer');

			if ($renderer instanceof LayoutHelper)
			{
				$this->renderer = $renderer;
			}
			else
			{
				$this->renderer = easyshop('renderer');
			}
		}

		return $this->renderer;
	}

	public function setRenderer(LayoutHelper $renderer)
	{
		$this->renderer = $renderer;
	}

	protected function beforeDisplay()
	{
		return;
	}

	public function display($tpl = null)
	{
		$this->beforeDisplay();

		parent::display($tpl);
	}

	public function getProperty($property, $default = null)
	{
		return property_exists($this, $property) ? $this->{$property} : $default;
	}
}
