<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

namespace ES\View;

use ES\Helper\Navbar;

defined('_JEXEC') or die;
\JLoader::import('easyshop.view.legacy');

class ViewList extends ViewLegacy
{
	protected $items;
	protected $state;
	protected $pagination;
	protected $showNavbar = true;
	protected $useFilter = true;
	protected $addToolbar = true;
	protected $navbar;
	public $filterForm;
	public $activeFilters;

	public function display($tpl = null)
	{
		$this->items      = $this->get('Items');
		$this->state      = $this->get('State');
		$this->pagination = $this->get('Pagination');

		if ($this->useFilter)
		{
			$this->filterForm    = $this->get('FilterForm');
			$this->activeFilters = $this->get('ActiveFilters');
		}

		if (count($errors = $this->get('Errors')))
		{
			throw new \Exception(implode("\n", $errors), 500);
		}

		if ($this->addToolbar && $this->getLayout() != 'modal')
		{
			$this->addToolbar();
		}

		$this->navbar = $this->showNavbar ? Navbar::render() : null;

		parent::display($tpl);
	}

	protected function addToolbar()
	{
		\JLoader::register('JToolbarHelper', JPATH_ADMINISTRATOR . '/includes/toolbar.php');
		$user = easyshop('class.user');
		$name = $this->getName();

		\JToolbarHelper::title(\JText::_('COM_EASYSHOP_' . strtoupper($name) . '_MANAGE'));

		if ($user->core('create'))
		{
			$stringHelper = easyshop('class.StringHelper');
			\JToolbarHelper::addNew($stringHelper->toSingular($name) . '.add');
		}

		if ($user->core('edit.state'))
		{
			\JToolbarHelper::publish($name . '.publish');
			\JToolbarHelper::unpublish($name . '.unpublish');

			if ($this->state->get('filter.published') == -2 && $user->core('delete'))
			{
				\JToolbarHelper::deleteList('', $name . '.delete');
			}
			else
			{
				\JToolbarHelper::trash($name . '.trash');
			}

			if ($user->core('edit.state'))
			{
				\JToolbarHelper::checkin($name . '.checkin');
			}
		}

		if ($user->core('admin'))
		{
			\JToolbarHelper::preferences('com_easyshop');
		}

	}

	public function getFormLayout($layoutId)
	{
		return $this->getRenderer()->render('view.list.' . $layoutId, $this);
	}

	protected function getItemLink($id = 0, Array $append = [], $key = 'id')
	{
		$name         = $this->getName();
		$stringHelper = easyshop('class.StringHelper');
		$link         = 'index.php?option=com_easyshop&task=' . $stringHelper->toSingular($name) . '.edit';

		if (count($append))
		{
			$link .= '&' . http_build_query($append);
		}

		$link .= '&' . $key . '=' . $id;

		return \JRoute::_($link, false);
	}

}
