<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.controller.legacy');
use ES\Controller\ControllerLegacy;

class EasyshopControllerAjax extends ControllerLegacy
{
	public function validateVat()
	{
		JLoader::register('EasyshopRuleVat', ES_COMPONENT_ADMINISTRATOR . '/models/rules/vat.php');
		$vat      = $this->input->get('vatNumber');
		$required = $this->input->get('required');
		$response = EasyshopRuleVat::isValid($vat, $required);
		echo new JResponseJson($response);

		$this->app->close();
	}

	public function loadPrintPage()
	{
		try
		{
			/** @var \ES\Order $order */
			$orderId = (int) $this->app->input->getUint('orderId', 0);
			$order   = easyshop('class.order');

			if (!$order->load($orderId))
			{
				throw new RuntimeException(JText::sprintf('COM_EASYSHOP_ERROR_ORDER_NOT_FOUND', $orderId));
			}

			$vendorId                 = (int) $order->get('vendor_id', 0);
			$displayData              = easyshop('class.utility')->getShopInformation($vendorId);
			$displayData['order']     = $order;
			$displayData['pageTitle'] = $this->app->input->getString('pageTitle', JText::_('COM_EASYSHOP_ORDER_PRINT_TITLE'));
			$displayData['shipping']  = null;
			$displayData['payment']   = null;
			$shippingId               = $order->get('shipping_id', 0);
			$paymentId                = $order->get('payment_id', 0);

			if ($shippingId || $paymentId)
			{
				$methodClass = easyshop('class.method');

				if ($shippingId && ($shipping = $methodClass->get($shippingId)))
				{
					$displayData['shipping'] = $shipping;
				}

				if ($paymentId && ($payment = $methodClass->get($paymentId)))
				{
					$displayData['payment'] = $payment;
				}
			}

			$response = easyshop('renderer')->render('print.print', $displayData);
		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response);

		$this->app->close();
	}

	public function loadImage()
	{
		/** @var \ES\Media $mediaClass */
		$mediaClass          = easyshop('class.media');
		$size                = $this->app->input->getString('size');
		$imageBaseFilePath   = base64_decode($this->app->input->getBase64('file'));
		$resultImageBasePath = JPATH_ROOT . '/' . $mediaClass->getResizeImageBasePath($imageBaseFilePath, $size, true);

		if (!is_file($resultImageBasePath))
		{
			throw new RuntimeException('Image file not exists.');
		}

		header('Content-type: ' . $mediaClass->getMimeByFile($resultImageBasePath));
		readfile($resultImageBasePath);

		$this->app->close();
	}
}
