<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

use ES\Controller\ControllerLegacy;
use ES\Plugin\Payment;

class EasyshopControllerCheckout extends ControllerLegacy
{
	/**
	 * @var $cart \ES\Cart
	 * @since 1.0.0
	 */
	protected $cart;

	public function __construct(array $config)
	{
		parent::__construct($config);

		$this->cart = easyshop('class.cart');
	}

	protected function getForm()
	{
		/**
		 * @var $form  \JForm
		 * @var $model \EasyshopModelCheckout
		 */
		static $form = null;

		if (null === $form)
		{
			$model = easyshop('model', 'Checkout');
			$form  = $model->getForm(false);
		}

		if (!$form)
		{
			$this->app->enqueueMessage($model->getError(), 'error');

			return false;
		}

		return $form;
	}

	protected function validate($groups = null, $throw = false)
	{
		/** @var \Joomla\CMS\Form\Form $form */
		$form        = $this->getForm();
		$jform       = $form->filter($this->app->input->get('jform', [], 'array'));
		$data        = array_merge($this->cart->getCheckoutData(), $jform);
		$disableShip = easyshop('disable_shipping_address', 0);

		if (empty($jform['address_different']) || $disableShip)
		{
			$data['shipping_address']  = $data['billing_address'];
			$data['address_different'] = 0;
		}

		if (empty($jform['confirm']['terms_and_conditions']))
		{
			$data['confirm']['terms_and_conditions'] = 0;
		}

		$this->cart->setCheckoutData($data, true);
		$return = [];

		if (null === $groups)
		{
			$return[] = $form->validate($data);
		}
		else
		{
			foreach ($groups as $group)
			{
				if ($form->getGroup($group))
				{
					$return[] = $form->validate($data, $group);
				}
			}
		}

		if (in_array(false, $return, true))
		{
			$errors = $form->getErrors();

			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++)
			{
				if ($errors[$i] instanceof Exception)
				{
					$message = $errors[$i]->getMessage();
				}
				else
				{
					$message = $errors[$i];
				}

				if ($throw)
				{
					throw new RuntimeException($message);
				}

				$this->app->enqueueMessage($message, 'warning');
			}

			return false;
		}

		return $data;
	}

	protected function loadLayout($layout = 'checkout')
	{
		$controller = ControllerLegacy::getInstance('Easyshop', ['base_path' => ES_COMPONENT_SITE]);
		$view       = $controller->getView('Cart', 'html', 'EasyshopView', ['base_path' => ES_COMPONENT_SITE . '/views']);
		$view->setLayout($layout);
		ob_end_clean();
		ob_start();
		$view->display();

		return ob_get_clean();
	}

	public function saveAddress()
	{
		try
		{
			if (!JSession::checkToken('get'))
			{
				throw new RuntimeException(JText::_('JINVALID_TOKEN'));
			}

			$data = $this->validate(['billing_address', 'shipping_address', 'checkoutFields'], true);
			$this->cart->setCheckoutData($data, true);
			$data = $this->cart->getCheckoutData();

			if (!empty($data['shipping_id']))
			{
				/** @var $method \ES\Method */
				$method = easyshop('class.method');
				$found  = false;

				foreach ($method->getGroup('easyshopshipping') as $shipping)
				{
					if ((int) $shipping->id === (int) $data['shipping_id'])
					{
						$found = true;
						break;
					}
				}

				if (!$found)
				{
					$this->cart->setCheckoutData(['shipping_id' => 0], true);
				}
			}

			$response = [
				'pushState' => [
					'url'   => JRoute::_(EasyshopHelperRoute::getCartRoute('confirm'), false),
					'title' => JText::_('COM_EASYSHOP_PAGE_CHECKOUT_CONFIRM_TITLE'),
				],
				'html'      => $this->loadLayout('confirm'),
			];
		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response);
		$this->app->close();
	}

	public function editAddress()
	{
		try
		{
			if (!JSession::checkToken('get'))
			{
				throw new RuntimeException(JText::_('JINVALID_TOKEN'));
			}

			$doc      = easyshop('doc');
			$response = [
				'pushState' => [
					'url'   => JRoute::_(EasyshopHelperRoute::getCartRoute('checkout'), false),
					'title' => JText::_('COM_EASYSHOP_PAGE_CHECKOUT_ADDRESS_TITLE'),
				],
				'html'      => $this->loadLayout(),
			];

			$response['_scripts']     = $doc->_scripts;
			$response['_script']      = $doc->_script;
			$response['_styleSheets'] = $doc->_styleSheets;
			$response['_style']       = $doc->_style;
		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response);
		$this->app->close();
	}

	public function guest()
	{
		$this->checkToken('post');
		$return = base64_decode($this->app->input->post->getBase64('return'));
		$form   = $this->app->input->post->get('jform', [], 'array');

		if (easyshop('config', 'guest_checkout', 1))
		{
			if (empty($form['guest']['email']) || !filter_var($form['guest']['email'], FILTER_VALIDATE_EMAIL))
			{
				$this->app->enqueueMessage(JText::_('COM_EASYSHOP_ERROR_INVALID_EMAIL'), 'error');
			}
			else
			{
				$data = ['guest' => $form['guest']];
				$this->cart->setCheckoutData($data, true);
			}

			if (!empty($data['guest']['email']))
			{
				$return = JRoute::_(EasyshopHelperRoute::getCartRoute('checkout'));
			}
		}

		$this->app->redirect($return);
	}

	public function finished()
	{
		/**
		 * @var $form           \JForm
		 * @var $currency       \ES\Currency
		 * @var $model          \EasyshopModelCheckout
		 * @var $order          \ES\Order
		 * @var $emailClass     \ES\Email
		 * @var $customField    \ES\CustomField
		 * @var $app            \JApplicationCms
		 * @var $paymentHandler \ES\Payment
		 */
		$this->checkToken();
		$cart            = $this->cart;
		$order           = easyshop('class.order');
		$currency        = easyshop('class.currency')->getActive();
		$user            = JFactory::getUser();
		$app             = easyshop('app');
		$redirect        = JRoute::_(EasyshopHelperRoute::getCartRoute('confirm'), false);
		$jform           = $app->input->get('jform', [], 'array');
		$paymentMethods  = $cart->getPaymentMethods();
		$shippingMethods = $cart->getShippingMethods();
		$extractData     = null;
		$paymentHandler  = null;

		$app->setUserState('com_easyshop.checkoutPostFormData', $jform);
		$app->triggerEvent('onEasyshopCheckoutPrepareCartData', [&$extractData]);

		if (null === $extractData)
		{
			$extractData = $cart->extractData();
		}

		try
		{
			$data = $this->validate(['billing_address', 'shipping_address', 'checkoutFields'], true);
			$form = $this->getForm();

			if (easyshop('config', 'terms_and_conditions', 1))
			{
				if (empty($data['confirm']['terms_and_conditions']))
				{
					throw new RuntimeException(JText::_('COM_EASYSHOP_TERMS_AND_CONDITIONS_CONFIRM_WARNING'));
				}

				$form->removeField('terms_and_conditions', 'confirm');
			}

			$this->validate(['confirm'], true);

			if ((int) $extractData['count'] < 1)
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_YOUR_CART_EMPTY'));
			}

			if (empty($data['billing_address']) || empty($data['shipping_address']))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_INVALID_ADDRESS'));
			}

			if (!($payment = $cart->getPaymentMethods(true))
				&& $paymentMethods
			)
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_NO_PAYMENT'));
			}

			if (is_object($payment))
			{
				/** @var $payment \stdClass */
				$payment->data = [];

				if (!empty($payment->cardForm))
				{
					$payment->card = [];
					$card          = [
						'holderName'  => 'card_holder_name_' . $payment->id,
						'number'      => 'card_number_' . $payment->id,
						'expiryMonth' => 'card_expiry_month_' . $payment->id,
						'expiryYear'  => 'card_expiry_year_' . $payment->id,
						'cvv'         => 'card_cvv_' . $payment->id,
					];

					foreach ($card as $name => $request)
					{
						$payment->card[$name] = isset($jform[$request]) ? $jform[$request] : '';
					}
				}

				JPluginHelper::importPlugin('easyshoppayment', $payment->element);
				$paymentHandler = Payment::getHandler($payment->element);

				if (!($paymentHandler instanceof Payment))
				{
					throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_INVALID_PAYMENT_HANDLER'));
				}

				$currencies   = $paymentHandler->getCurrencies();
				$currencyCode = strtoupper($currency->get('code', ''));

				if ($currencies && !in_array($currencyCode, array_map('strtoupper', $currencies), true))
				{
					throw new RuntimeException(JText::sprintf('COM_EASYSHOP_ERROR_INVALID_PAYMENT_CURRENCY_FORMAT', $payment->name, $currencyCode));
				}

				$payment->data   = isset($jform['paymentData'][$payment->id]) ? $jform['paymentData'][$payment->id] : [];
				$clonePayment    = clone $payment;
				$paymentValidate = $paymentHandler->validate($clonePayment);

				if (false === $paymentValidate)
				{
					throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_PAYMENT_VALIDATE_FAIL'));
				}
			}

			if (!($shipping = $cart->getShippingMethods(true))
				&& $shippingMethods
			)
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_NO_SHIPPING'));
			}

			$order->setCurrency($currency);
			$orderData = [
				'shipping_id'      => $shipping ? (int) $shipping->id : 0,
				'payment_id'       => $payment ? (int) $payment->id : 0,
				'billing_address'  => $data['billing_address'],
				'shipping_address' => $data['shipping_address'],
				'checkoutFields'   => isset($data['checkoutFields']) ? $data['checkoutFields'] : [],
				'state'            => 0, // 0 => new, 1 => confirm, 2 => processed, 3 => shipped, 4 => succeed, 5 => cancelled, -2 => trash. Will be applied by admin or payment handler
				'payment_status'   => 0,  // 0 => unpaid, 1 => paid, 2 => refund. Will be applied by payment plugin or payment handler
				'total_shipping'   => $shipping ? $currency->convert($shipping->total) : 0.00,
				'total_paid'       => 0.00,// Will be applied by payment plugin or admin in the back-end
				'currency_id'      => $currency->get('id'),
				'items'            => $extractData['items'],
				'total_discount'   => $currency->convert($extractData['orderDiscount']),
				'total_price'      => $currency->convert($extractData['grandTotal']),
				'total_taxes'      => $currency->convert($extractData['totalTaxes']),
				'total_fee'        => $currency->convert($extractData['paymentFee']),
				'discounts'        => $extractData['discounts'],
			];

			if (isset($data['note']))
			{
				$orderData['note'] = JFilterOutput::cleanText($data['note']);
			}

			if ($user->id)
			{
				JTable::addIncludePath(ES_COMPONENT_ADMINISTRATOR . '/tables');
				$userTable = JTable::getInstance('User', 'EasyshopTable');

				if ($userTable->load(['user_id' => $user->id]))
				{
					$orderData['user_id'] = $userTable->get('id');
				}

				$orderData['user_email'] = $user->get('email');
			}
			elseif (@filter_var($data['guest']['email'], FILTER_VALIDATE_EMAIL))
			{
				$orderData['user_email'] = $data['guest']['email'];
			}
			else
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_USER_EMAIL'));
			}

			$app->triggerEvent('onEasyshopCheckoutPrepareOrderData', [$order, &$orderData]);

			if (!$order->save($orderData))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ORDER_SAVE_FAIL_MESSAGE'));
			}

			// Fire the event before payment and send email
			$message    = trim(join(PHP_EOL, $app->triggerEvent('onEasyshopOrderCreated', [$order])));
			$emailClass = easyshop('class.email');
			$emailClass->sendOn('[ON_NEW_ORDER]', $order->getLayoutData(), $order);

			if ($paymentHandler instanceof Payment)
			{
				if ($paymentHandler->loadOrder($order, $payment->data))
				{
					try
					{
						$paymentReturn = $paymentHandler->execute();

						if (!empty($paymentReturn) && is_string($paymentReturn))
						{
							$message .= trim($paymentReturn);
						}
					}
					catch (Exception $paymentException)
					{
						$app->enqueueMessage($paymentException->getMessage(), 'warning');
					}
				}
			}

			$data['finalData'] = easyshop('renderer')->render('checkout.message.success', [
				'order'   => $order,
				'message' => $message,
			]);

			if (empty($data['finalData']))
			{
				$data['finalData'] = '<div></div>';
				$app->enqueueMessage(JText::sprintf('COM_EASYSHOP_CHECKOUT_SUCCESS_MESSAGE', $orderData['order_code']), 'success');
			}

			// Fire the event after render success message and redirect to the finished page.
			$app->triggerEvent('onEasyshopOrderFinished', [$order, &$data['finalData']]);
			$this->cart->setCheckoutData($data);
		}
		catch (RuntimeException $e)
		{
			$app->enqueueMessage($e->getMessage(), 'warning');
		}

		$app->redirect($redirect);
	}

	protected function addMethod($type)
	{
		/** @var $methodClass \ES\Method */
		$methodClass = easyshop('class.method');
		$methodId    = (int) $this->input->post->getInt($type . 'Id', 0);
		$found       = false;
		$func        = 'get' . ucfirst($type) . 'Methods';
		try
		{
			foreach ($methodClass->$func() as $method)
			{
				if ((int) $method->id === $methodId)
				{
					$found = true;
					break;
				}
			}

			if (!$found)
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_INVALID_' . strtoupper($type) . '_ID'));
			}

			$this->cart->setCheckoutData([
				$type . '_id' => $methodId,
			], true);

			$response = $this->loadLayout('confirm');
		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response);
		$this->app->close();
	}

	public function addShipping()
	{
		$this->addMethod('shipping');
	}

	public function addPayment()
	{
		$this->addMethod('payment');
	}
}
