<?php

/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

class EasyshopControllerComment extends JControllerLegacy
{
	public function send()
	{
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		/**
		 * @var $utility      \ES\Utility
		 * @var $productClass \ES\Product
		 */

		$utility      = easyshop('class.Utility');
		$productClass = easyshop('class.Product');
		$config       = easyshop('config');
		$accessGroups = $config->get('access_comment_groups', []);

		try
		{
			if (count($accessGroups) && !$utility->userAccess($accessGroups))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_LOGIN_REQUIRED_MSG'));
			}

			JTable::addIncludePath(ES_COMPONENT_ADMINISTRATOR . '/tables');
			$reviewTable = JTable::getInstance('Review', 'EasyshopTable');

			if ($config->get('comment_name', 1))
			{
				$name = trim($this->input->post->getString('name'));

				if (empty($name))
				{
					throw new RuntimeException(JText::_('COM_EASYSHOP_YOUR_NAME_REQUIRED_MSG'));
				}

				$reviewTable->set('user_name', $name);
			}

			if ($config->get('comment_email', 1))
			{
				$email = trim($this->input->post->getString('email'));

				if (empty($email) || !filter_var($email, FILTER_VALIDATE_EMAIL))
				{
					throw new RuntimeException(JText::_('COM_EASYSHOP_YOUR_EMAIL_REQUIRED_MSG'));
				}

				$reviewTable->set('user_email', $email);
			}

			$message = trim($this->input->post->getString('comment'));

			if (empty($message))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_COMMENT_REQUIRED_MSG'));
			}

			$productId = (int) $this->input->post->getInt('product_id', 0);

			if (!$productClass->isEnabled($productId))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_PRODUCT_NOT_FOUND'));
			}

			if (isset($_COOKIE['product_vote_' . $productId]))
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_YOU_HAVE_RATED_FOR_THIS_PRODUCT_MSG'));
			}

			$vote = (int) $this->input->post->getInt('user_vote');

			if ($vote < 1)
			{
				throw new RuntimeException(JText::_('COM_EASYSHOP_VOTE_REQUIRED_MSG'));
			}

			$vote = $vote > 5 ? 5 : $vote;

			$reviewTable->set('state', $config->get('comment_published', 0) ? 1 : 0);
			$reviewTable->set('user_vote', $vote);
			$reviewTable->set('product_id', $productId);
			$reviewTable->set('user_comment', $message);
			$reviewTable->set('created_date', JFactory::getDate()->toSql());
			$reviewTable->set('user_ip', @$_SERVER['REMOTE_ADDR']);
			$reviewTable->set('user_agent', @$_SERVER['HTTP_USER_AGENT']);

			if (!empty($_SERVER['HTTP_REFERER']))
			{
				$referer = str_replace(JUri::root(), '', $_SERVER['HTTP_REFERER']);
				$reviewTable->set('referer', $referer);
			}

			$reviewTable->set('juser_id', JFactory::getUser()->id);

			if (!$reviewTable->check() || !$reviewTable->store())
			{
				throw new RuntimeException($reviewTable->getError());
			}

			$product  = $productClass->getItem($productId);
			$response = easyshop('class.LayoutHelper')->render('product.comment.list', ['product' => $product]);
			$message  = $reviewTable->get('state') ? JText::_('COM_EASYSHOP_COMMENT_SUCCESS') : JText::_('COM_EASYSHOP_COMMENT_COMMENT_WAIT_FOR_APPROVE');

			setcookie('product_vote_' . $productId, true, time() + (86400 * 30), JUri::root(true) . '/');

		}
		catch (RuntimeException $e)
		{
			$response = $e;
		}

		echo new JResponseJson($response, !empty($message) ? $message : null);

		easyshop('app')->close();
	}
}
