<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
/**
 * @var $currency      \ES\Currency
 * @var $utility       \ES\Utility
 * @var $order         \ES\Order
 * @var $userClass     \ES\User
 * @var $renderer      \ES\LayoutHelper
 * @var $orderForm     \JForm
 * @var $payment       \stdClass
 */
extract($displayData);
$userClass = easyshop('class.user');
$utility   = easyshop('class.utility');
$userClass->load($orderForm->getValue('user_id'));
$paymentStatus = $order->getPaymentStatus();
$orderStatus   = $order->getOrderStatus();
$orderState    = (int) $orderForm->getValue('state');
$currency      = $order->get('currency');
JHtml::_('easyshop.printOrder', $order->id, JText::sprintf('COM_EASYSHOP_ORDER_PRINT_TITLE_FORMAT', $order->order_code));
?>
<div id="es-customer-order" class="es-detail-panel">
    <div id="es-toolbar" class="uk-clearfix uk-padding-small uk-background-muted uk-margin">
        <form action="" method="post">
            <div class="uk-button-group">
                <button type="button" data-task="customer.goBackPage"
                        class="uk-button uk-button-default uk-button-small">
                    <span uk-icon="icon: reply"></span>
					<?php echo JText::_('COM_EASYSHOP_GO_BACK'); ?>
                </button>
                <button type="button"
                        id="es-print-order"
                        class="uk-button uk-button-primary uk-button-small uk-float-left">
                    <i class="fa fa-print"></i>
					<?php echo JText::_('COM_EASYSHOP_PRINT'); ?>
                </button>
            </div>
			<?php if ($orderState === ES_ORDER_CREATED): ?>
                <button type="button" data-task="customer.cancelOrder"
                        class="uk-button uk-button-secondary uk-button-small uk-float-right">
                    <span uk-icon="icon: ban"></span>
					<?php echo JText::_('COM_EASYSHOP_CANCEL_THIS_ORDER'); ?>
                </button>
			<?php endif; ?>
            <input name="task" type="hidden" value=""/>
			<?php echo JHtml::_('form.token'); ?>
        </form>
    </div>
    <div id="es-order-print" class="uk-grid-small" uk-height-match="target: .uk-panel" uk-grid>
        <div class="uk-width-1-2@m">
            <fieldset class="uk-form-horizontal uk-fieldset">
                <div class="uk-panel">
                    <div class="uk-h5 uk-text-uppercase uk-margin-remove-top uk-margin-small-bottom">
                        <span uk-icon="icon: info"></span>
						<?php echo JText::_('COM_EASYSHOP_MAIN_INFORMATION'); ?>
                    </div>
					<?php echo $renderer->render('order.general', [
						'form'          => $orderForm,
						'orderStatus'   => $orderStatus,
						'paymentStatus' => $paymentStatus,
						'currency'      => $currency,
						'utility'       => $utility,
						'customerName'  => $userClass->getName(),
					]); ?>
                </div>
            </fieldset>
        </div>
        <div class="uk-width-1-2@m">
            <fieldset class="uk-form-horizontal uk-fieldset">
                <div class="uk-panel">
                    <div class="uk-h5 uk-text-uppercase uk-margin-remove-top uk-margin-small-bottom">
                        <span uk-icon="credit-card"></span>
						<?php echo JText::_('COM_EASYSHOP_PAYMENT'); ?>
                    </div>
					<?php echo $renderer->render('order.payment', [
						'form'          => $orderForm,
						'orderStatus'   => $orderStatus,
						'paymentStatus' => $paymentStatus,
						'currency'      => $currency,
						'utility'       => $utility,
					]); ?>
					<?php if (is_object($payment) && !empty($payment->orderArea)): ?>
						<?php echo $payment->orderArea; ?>
					<?php endif; ?>
                </div>
            </fieldset>
        </div>
        <div class="uk-width-1-2@m">
            <fieldset class="uk-form-horizontal uk-fieldset" data-zone-group>
                <div class="uk-panel">
                    <div class="uk-h5 uk-text-uppercase uk-margin-small-bottom">
	                    <?php echo JHtml::_('easyshop.svgIcon', 'bill.svg'); ?>
						<?php echo JText::_('COM_EASYSHOP_BILLING_ADDRESS'); ?>
                    </div>
					<?php echo $utility->formatAddress($order->address['billing']); ?>
                </div>
            </fieldset>
        </div>
        <div class="uk-width-1-2@m">
            <fieldset class="uk-form-horizontal uk-fieldset" data-zone-group>
                <div class="uk-panel">
                    <div class="uk-h5 uk-text-uppercase uk-margin-remove-top uk-margin-small-bottom">
	                    <?php echo JHtml::_('easyshop.svgIcon', 'truck.svg'); ?>
						<?php echo JText::_('COM_EASYSHOP_SHIPPING_ADDRESS'); ?>
                    </div>
					<?php echo $utility->formatAddress($order->address['shipping']); ?>
                </div>
            </fieldset>
        </div>
    </div>
	<?php echo $renderer->render('order.cart', [
		'order'    => $order,
		'currency' => $currency,
		'utility'  => $utility,
		'noAction' => true,
	]); ?>
</div>
<script>
    _es.$(document).ready(function ($) {
        $('form button[data-task]').on('click', function () {
            var task = $(this).data('task');
            this.form.task.value = task;
            if (task === 'customer.cancelOrder' && !confirm('<?php echo JText::_('COM_EASYSHOP_ORDER_CANCELLED_CONFIRM', true); ?>')) {
                return false;
            }
            this.form.submit();
        });
    });
</script>
