<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
$view           = $displayData['view'];
$product        = $displayData['product'];
$priceConfig    = $displayData['config']->get('product_' . $view . '_prices', 'price_n_taxes');
$showPriceRules = $displayData['config']->get('product_' . $view . '_show_price_by_qty', 1);

// @since 1.2.3, check permission
$userClass = easyshop('class.user');
$groups    = $displayData['config']->get('groups_can_view_price', []);
$canView   = (empty($groups) || $userClass->accessGroups($groups, true)) && ($priceConfig == 'price_n_taxes' || $priceConfig == 'price');

?>

<?php if ($canView): ?>
    <div class="product-price" itemprop="offers" itemscope itemtype="http://schema.org/Offer">
        <meta itemprop="price" content="<?php echo $product->retailPrice; ?>"/>
        <meta itemprop="priceCurrency" content="<?php echo $product->currency; ?>"/>
        <div class="product-sale-price uk-display-inline-block"
             data-product-price="<?php echo $product->salePrice; ?>">
			<?php echo $product->priceFormat; ?>
        </div>

		<?php if (!empty($product->oldPriceFormat)): ?>
            <div class="product-price-old uk-display-inline-block">
				<?php echo $product->oldPriceFormat; ?>
            </div>
		<?php endif; ?>

		<?php

		if ($showPriceRules && $product->prices)
		{
			$outputHtml = '';
			$prices     = [];
			$currency   = easyshop('class.currency')->getActive();
			$currencyId = $currency->get('id');

			foreach ($product->prices as $price)
			{
				if (!$price->currency_id || $currencyId == $price->currency_id)
				{
					$prices[] = $price;
				}
			}

			foreach ($prices as $i => $price)
			{
				$minQty      = (int) $price->min_quantity;
				$next        = $i + 1;
				$priceFormat = $currency->toFormat($price->price_value, true);
				$maxQty      = isset($prices[$next]) ? $prices[$next]->min_quantity - 1 : false;
				$class       = isset($product->cart['quantity']) && $product->cart['quantity'] >= $minQty && $product->cart['quantity'] <= $maxQty ? ' class="active"' : '';

				if (false !== $maxQty)
				{
					$outputHtml .= '<li' . $class . ' data-range-qty="[' . $price->min_quantity . ', ' . $maxQty . ']">'
						. '<span uk-icon="icon: check"></span> '
						. JText::sprintf('COM_EASYSHOP_PRICE_FOR_RANGE_QUANTITY_FORMAT', $price->min_quantity, $maxQty, $priceFormat)
						. '</li>';
				}
				else
				{
					$outputHtml .= '<li' . $class . ' data-range-qty="[' . $price->min_quantity . ', 999999]">'
						. '<span uk-icon="icon: check"></span> '
						. JText::sprintf('COM_EASYSHOP_PRICE_FOR_MIN_QUANTITY_FORMAT', $price->min_quantity, $priceFormat)
						. '</li>';
				}
			}

			if ($outputHtml)
			{
				echo '<ul class="uk-list uk-margin-small es-price-range-qty">' . $outputHtml . '</ul>';
			}
		}

		?>

		<?php if ($priceConfig == 'price_n_taxes' && $product->totalTaxes > 0.00): ?>
            <div class="product-taxes">
                <span class="uk-text-meta"><?php echo JText::_('COM_EASYSHOP_TAXES'); ?></span>
                <span data-product-taxes="<?php echo $product->saleTaxes; ?>">
            <?php echo $product->taxesFormat; ?>
        </span>
            </div>
		<?php endif; ?>
    </div>
<?php endif; ?>
