<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.model.admin');

use ES\Model\ModelAdmin;

class EasyshopModelCustomer extends ModelAdmin
{
	public function getUser($load = true)
	{
		static $user = null;

		if (null === $user)
		{
			/** @var $user \ES\User */
			$user = easyshop('class.user');
		}

		if ($load)
		{
			if (!$user->load())
			{
				$jUserId = (int) $user->get()->id;

				if ($jUserId > 0)
				{
					JTable::addIncludePath(ES_COMPONENT_ADMINISTRATOR . '/tables');
					$userTable = JTable::getInstance('User', 'EasyshopTable');

					if (!$userTable->load(['user_id' => $jUserId]))
					{
						$userTable->bind([
							'user_id' => $jUserId,
							'state'   => 1,
						]);
						$userTable->store();
					}
				}
			}
		}

		return $user;
	}

	public function getForm($data = [], $loadData = true)
	{
		JForm::addFieldPath(ES_COMPONENT_ADMINISTRATOR . '/models/fields');
		JForm::addFormPath(ES_COMPONENT_SITE . '/models/forms');
		JForm::addRulePath(ES_COMPONENT_ADMINISTRATOR . '/models/rules');
		/**@var $customField \ES\CustomField */
		$user        = $this->getUser();
		$customField = easyshop('class.customField', [
			'reflector'    => 'com_easyshop.user',
			'reflector_id' => $user->id,
		]);
		$addressForm = $customField->getFormFieldData(0, ['checkout_field' => 1]);
		$form        = new JForm('com_easyshop.customer', ['control' => 'jform']);
		$formData    = [];

		if ($user->id && (int) $user->state !== 1)
		{
			throw new RuntimeException(JText::sprintf('COM_EASYSHOP_USER_WAS_BANNED_WARNING', $user->getName()));
		}

		if ($user->user_id)
		{
			$form->loadFile('profile');
		}
		else
		{
			$form->loadFile('guest');
			$tfa = JAuthenticationHelper::getTwoFactorMethods();

			if (!is_array($tfa) || count($tfa) <= 1)
			{
				$form->removeField('secretkey', 'login');
			}
		}

		if ($form->load($addressForm['form']))
		{
			if ($customField->findFieldByName('user_name'))
			{
				$form->removeField('name', 'registration');
			}

			if ($loadData)
			{
				if ($user->id)
				{
					JFactory::getLanguage()->load('com_users');
					$jUser    = $user->get();
					$formData = [
						'id'           => $user->id,
						'avatar'       => $user->avatar,
						'name'         => $jUser->name,
						'username'     => $jUser->username,
						'email1'       => $jUser->email,
						'email2'       => $jUser->email,
						'customfields' => $addressForm['data'],
						'timezone'     => $jUser->getParam('timezone', ''),
						'secret_key'   => $user->secret_key,
					];
				}
				else
				{
					$formData = easyshop('app')->getUserState('com_easyshop.customer.registration.data', []);
				}

				$form->bind($formData);
			}
		}

		$this->postFormHook($form, $formData);

		return $form;
	}

	public function register($data)
	{
		/** @var $customField \ES\CustomField */
		$customField = easyshop('class.customField', [
			'reflector' => 'com_easyshop.user',
		]);

		if (!empty($data['customfields']))
		{
			$fieldName = $customField->findFieldByName('user_name');

			if ($fieldName && isset($data['customfields'][$fieldName->id]))
			{
				$name         = trim($data['customfields'][$fieldName->id], '[]');
				$data['name'] = str_replace('][', ' ', $name);
			}
			else
			{
				$data['name'] = $data['email'];
			}
		}

		if (isset($data['timezone']))
		{
			$data['params'] = [
				'admin_style'    => '',
				'admin_language' => '',
				'language'       => '',
				'editor'         => '',
				'helpsite'       => '',
				'timezone'       => $data['timezone'],
			];
			unset($data['timezone']);
		}

		JFactory::getLanguage()->load('com_users');
		$config       = easyshop('config');
		$autoActivate = $config->get('user_auto_activate', 1);
		$userId       = null;

		if ($autoActivate)
		{
			JPluginHelper::importPlugin('user');
			$userConfig = JComponentHelper::getParams('com_users');
			$user       = new JUser;
			$userData   = [
				'id'       => 0,
				'name'     => $data['name'],
				'username' => $data['username'],
				'email'    => JStringPunycode::emailToPunycode($data['email1']),
				'password' => $data['password1'],
				'params'   => isset($data['params']) ? $data['params'] : [],
				'groups'   => [$userConfig->get('new_usertype', 2)], // Get the default new user group, Registered if not specified.
				'block'    => 0,
			];

			$result = ($user->bind($userData) && $user->save());

			if (!$result)
			{
				$this->setError(JText::sprintf('COM_USERS_REGISTRATION_SAVE_FAILED', $user->getError()));
			}

			$userId = (int) $user->id;
		}
		else
		{
			if (ES_DETECT_JVERSION == 4)
			{
				JModelLegacy::addIncludePath(JPATH_SITE . '/components/com_users/Model', 'Joomla\Component\Users\Site\Model\\');
				JForm::addFormPath(JPATH_SITE . '/components/com_users/forms');
				$registrationModel = JModelLegacy::getInstance('RegistrationModel', 'Joomla\Component\Users\Site\Model\\');
			}
			else
			{
				JModelLegacy::addIncludePath(JPATH_SITE . '/components/com_users/models', 'UsersModel');
				JForm::addFormPath(JPATH_SITE . '/components/com_users/models/forms');
				$registrationModel = JModelLegacy::getInstance('Registration', 'UsersModel');
			}

			$result = $registrationModel->register($data);

			if (false === $result)
			{
				$this->setError($registrationModel->getError());
			}
			else
			{
				$result = true;
			}
		}

		if ($result && !empty($data['customfields']))
		{
			if (null === $userId)
			{
				$userId = easyshop('state')->get('customer.juser_register_id');
			}

			$user = $this->getUser(false);

			if ($user->load(['user_id' => $userId]))
			{
				$customField->setUp(['reflector_id' => $user->id]);

				if ($result = $customField->save($data))
				{
					easyshop('app')->triggerEvent('onEasyshopCustomerRegister', [$user, $data]);
				}
			}
		}

		return $result;
	}
}
