<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;

class EasyshopRouter extends JComponentRouterBase
{
	public $app;
	public $menu;

	public function __construct($app = null, $menu = null)
	{
		$this->app  = JFactory::getApplication('site');
		$this->menu = $this->app->getMenu();
	}

	public function build(&$query)
	{
		$segments = [];

		if (isset($query['limitstart']) && $query['limitstart'] == 0)
		{
			unset($query['limitstart']);
		}

		if (empty($query['Itemid']))
		{
			$menuItem      = $this->menu->getActive();
			$menuItemGiven = false;
		}
		else
		{
			$menuItem      = $this->menu->getItem($query['Itemid']);
			$menuItemGiven = true;
		}

		if ($menuItemGiven
			&& isset($menuItem)
			&& $menuItem->component != 'com_easyshop'
		)
		{
			$menuItemGiven = false;
			unset($query['Itemid']);
		}

		if (isset($query['view']))
		{
			$view = $query['view'];
		}
		else
		{
			return $segments;
		}

		if (isset($menuItem))
		{
			$qView   = @$menuItem->query['view'];
			$qLayout = @$menuItem->query['layout'];

			if ($qView == $view
				&& isset($query['id'])
				&& isset($menuItem->query['id'])
				&& $menuItem->query['id'] == $query['id'])
			{
				if (isset($query['category_id']))
				{
					unset($query['category_id']);
				}

				unset($query['view'], $query['id']);

				if (isset($query['layout'])
					&& ($query['layout'] == 'default' || $query['layout'] == $menuItem->query['layout']))
				{
					unset($query['layout']);
				}

				return $segments;
			}

			$views = [
				'cart',
				'search',
				'customer',
				'track',
			];

			if ($qView == $view && in_array($qView, $views))
			{
				unset($query['view']);

				if ($qView == 'search'
					&& $qLayout == 'tag'
					&& isset($query['tag'])
				)
				{
					$segments = [$query['tag']];

					unset($query['tag']);

					if (isset($query['layout']))
					{
						unset($query['layout']);
					}

					return $segments;
				}

				if (isset($query['layout']))
				{
					if ($qView == 'cart' && $query['layout'] != 'default')
					{
						$string     = JText::_('COM_EASYSHOP_BUILD_ROUTE_ALIAS_' . strtoupper($query['layout']));
						$segments[] = JApplicationHelper::stringURLSafe($string);
					}

					unset($query['layout']);
				}

				return $segments;
			}
		}

		if ($view == 'productlist' || $view == 'productdetail')
		{
			if (!$menuItemGiven)
			{
				$segments[] = $view;
			}

			unset($query['view']);

			if (!isset($query['id']))
			{
				return $segments;
			}

			$db = easyshop('db');

			if ($view == 'productdetail')
			{
				if (!empty($query['category_id']))
				{
					$categoryId = $query['category_id'];
					unset($query['category_id']);

					// Make sure we have the id and the alias
					if (strpos($query['id'], ':') === false)
					{
						$dbQuery = $db->getQuery(true)
							->select('a.id, a.alias')
							->from($db->qn('#__easyshop_products', 'a'))
							->where('a.id = ' . (int) $query['id']);
						$db->setQuery($dbQuery);

						if ($product = $db->loadObject())
						{
							easyshop('prepare.product', $product);
							$query['id'] = $product->alias;
						}

					}
				}
				else
				{
					return $segments;
				}
			}
			else
			{
				$categoryId = $query['id'];
			}

			if ($menuItemGiven && isset($menuItem->query['id'])
			)
			{
				$mCatid = (int) $menuItem->query['id'];
			}
			else
			{
				$mCatid = 0;
			}

			$nodes    = JCategories::getInstance('easyshop.product');
			$category = $nodes->get($categoryId);

			if (!$category)
			{
				return $segments;
			}

			$path  = array_reverse($category->getPath());
			$array = [];

			foreach ($path as $id)
			{
				if ((int) $id == $mCatid)
				{
					break;
				}

				$ids     = explode(':', $id, 2);
				$array[] = $ids[1];
			}

			$array    = array_reverse($array);
			$segments = array_merge($segments, $array);

			if ($view == 'productdetail')
			{
				$segments[] = $query['id'];
			}

			unset($query['id']);
		}

		if (isset($query['layout']))
		{
			if ($menuItemGiven && isset($menuItem->query['layout']))
			{
				if ($query['layout'] == $menuItem->query['layout'])
				{
					unset($query['layout']);
				}
			}
			else
			{
				if ($query['layout'] == 'default')
				{
					unset($query['layout']);
				}
			}
		}

		$total = count($segments);

		for ($i = 0; $i < $total; $i++)
		{
			$segments[$i] = str_replace(':', '-', $segments[$i]);
		}

		return $segments;
	}

	protected function parseVars(&$vars, &$segments, $total, $item = null)
	{
		if ($total < 1)
		{
			return $vars;
		}

		$rootPath = '';
		$db       = easyshop('db');

		if ($item
			&& isset($item->query['option'])
			&& $item->query['option'] == 'com_easyshop'
			&& isset($item->query['view'])
			&& $item->query['view'] == 'productlist'
			&& isset($item->query['id'])
		)
		{
			$query = $db->getQuery(true)
				->select('a.path')
				->from($db->qn('#__categories', 'a'))
				->where('a.published = 1 AND a.id = ' . (int) $item->query['id']);
			$db->setQuery($query);

			if ($result = $db->loadResult())
			{
				$rootPath = trim($result) . '/';
			}
		}

		$path  = easyshop('prepare.categoryRoute', join('/', $segments));
		$alias = $segments[$total - 1];
		$query = $db->getQuery(true)
			->select('a.id')
			->from($db->qn('#__categories', 'a'))
			->where('a.extension = ' . $db->q('com_easyshop.product'))
			->where('a.published = 1 AND a.path = ' . $db->q($rootPath . $path));
		$db->setQuery($query);

		if (ES_DETECT_JVERSION == 4)
		{
			foreach ($segments as $k => $v)
			{
				unset($segments[$k]);
			}
		}

		if ($id = $db->loadResult())
		{
			$vars['view'] = 'productlist';
			$vars['id']   = (int) $id;

			return $vars;
		}

		$categoryPath = explode('/', $path);
		array_pop($categoryPath);
		$categoryPath = trim($rootPath . join('/', $categoryPath), '/');

		if (empty($categoryPath))
		{
			// Oops. Product detail URL must have parent category path
			return $vars;
		}

		$alias = easyshop('prepare.productRoute', $alias);
		$query = $db->getQuery(true)
			->select('a.id')
			->from($db->qn('#__easyshop_products', 'a'))
			->innerJoin($db->qn('#__categories', 'a2') . ' ON a2.id = a.category_id AND a2.extension = ' . $db->q('com_easyshop.product'))
			->where('a.state = 1 AND a.alias = ' . $db->q($alias))
			->where('a2.published = 1 AND a2.path = ' . $db->q($categoryPath));
		$db->setQuery($query);

		if ($id = $db->loadResult())
		{
			$vars['view'] = 'productdetail';
			$vars['id']   = (int) $id;
		}

		return $vars;
	}

	public function parse(&$segments)
	{
		// @since 1.1.5
		JPluginHelper::importPlugin('easyshop');

		$total = count($segments);
		$item  = $this->menu->getActive();
		$vars  = [];

		if (isset($item)
			&& @$item->query['view'] == 'search'
			&& @$item->query['layout'] == 'tag'
		)
		{
			return [
				'view' => 'search',
				'task' => 'search',
				'tag'  => $segments[0],
			];
		}

		if (!isset($item)
			|| @$item->query['option'] != 'com_easyshop'
		)
		{
			if (isset($segments[0]))
			{
				array_shift($segments);
				$total--;
			}

			return $this->parseVars($vars, $segments, $total, $item);
		}

		if ($total >= 1)
		{
			if ($total == 1)
			{
				static $loadLanguage = null;

				if (null === $loadLanguage)
				{
					$loadLanguage = JFactory::getLanguage()->load('com_easyshop', ES_COMPONENT_ADMINISTRATOR);
				}

				// If segments[0] the same with cart layout alias then it's cart view
				$key             = $segments[0];
				$cartLayoutAlias = [
					JApplicationHelper::stringURLSafe(JText::_('COM_EASYSHOP_BUILD_ROUTE_ALIAS_LOGIN'))    => 'login',
					JApplicationHelper::stringURLSafe(JText::_('COM_EASYSHOP_BUILD_ROUTE_ALIAS_CHECKOUT')) => 'checkout',
					JApplicationHelper::stringURLSafe(JText::_('COM_EASYSHOP_BUILD_ROUTE_ALIAS_CONFIRM'))  => 'confirm',
				];


				if (in_array($key, array_keys($cartLayoutAlias)))
				{
					$segments       = [];
					$vars['view']   = 'cart';
					$vars['layout'] = $cartLayoutAlias[$key];

					return $vars;
				}
			}

			return $this->parseVars($vars, $segments, $total, $item);
		}
	}
}

function easyshopBuildRoute(&$query)
{
	$router = new EasyshopRouter;

	return $router->build($query);
}

function easyshopParseRoute($segments)
{
	$router = new EasyshopRouter;

	return $router->parse($segments);
}
