<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
$renderer  = $this->getRenderer();
$config    = $this->config;
$imageSize = $config->get('product_detail_image_size', 'large');

if (!in_array($imageSize, ['tiny', 'small', 'medium', 'large', 'xlarge']))
{
	$imageSize = 'large';
}

$countImage   = count($this->product->images);
$leftWidth    = $countImage ? 'uk-width-1-2@s uk-width-1-3@m uk-width-2-5@l' : 'uk-width-1-1';
$rightWidth   = $countImage ? 'uk-width-1-2@s uk-width-2-3@m uk-width-3-5@l' : 'uk-width-1-1';
$absoluteLink = JUri::getInstance()->toString(['scheme', 'host']) . $this->product->link;
$thumbs       = '';

// Countdown @since 1.1.0
$countdown = (int) $this->product->params->get('product_detail_countdown', 0);

/**
 * @var $cartIconGroup boolean
 * @since 1.1.6
 */
$cartIconGroup = $config->get('cart_button_type', 'text_only') === 'icon_group';
?>
<div id="product-detail" itemscope itemtype="http://schema.org/Product">
    <meta itemprop="interactionCount" content="UserPageVisits:<?php echo $this->product->hits; ?>"/>
	<?php echo $this->event->execute('onProductBeforeDisplay'); ?>
    <div class="uk-grid uk-grid-small uk-margin-bottom" data-product-id="<?php echo $this->product->id; ?>">
		<?php if ($countImage): ?>
            <div class="<?php echo $leftWidth; ?>">
                <div class="es-product-images">
                    <div class="es-main-image uk-margin-small-bottom uk-text-center" uk-lightbox>
                        <a href="<?php echo $this->product->images[0]->image; ?>"
                           title="<?php echo htmlspecialchars($this->product->images[0]->title); ?>"
                           type="image">
							<?php echo $renderer->render('media.image', [
								'image'      => $this->product->images[0],
								'size'       => $imageSize,
								'attributes' => [
									'alt' => $this->product->images[0]->title,
								],
							]); ?>
                        </a>
                    </div>
					<?php if ($countImage > 1): ?>
                        <div uk-slider>
                            <div class="uk-position-relative uk-visible-toggle uk-light">
                                <ul class="uk-slider-items es-thumbnails-slider uk-child-width-1-2 uk-child-width-1-4@m uk-grid-small uk-grid"
                                    uk-lightbox>
									<?php foreach ($this->product->images as $i => $image): ?>
                                        <li data-image="<?php echo htmlspecialchars($image->originBasePath); ?>">
	                                        <?php if ($config->get('product_detail_thumb_cover')): ?>
                                                <div class="uk-cover-container">
                                                    <canvas width="100%"
                                                            height="<?php echo (int) $config->get('product_detail_thumb_height', '90'); ?>"></canvas>
			                                        <?php echo $renderer->render('media.image', [
				                                        'image'      => $image,
				                                        'size'       => $imageSize,
				                                        'attributes' => [
					                                        'alt'      => $image->title ?: $this->product->name,
					                                        'uk-cover' => '',
				                                        ],
			                                        ]); ?>
                                                </div>
	                                        <?php else: ?>
                                                <a href="<?php echo $image->large; ?>"
                                                   title="<?php echo htmlspecialchars($image->title); ?>"
                                                   type="image">
			                                        <?php echo $renderer->render('media.image', [
				                                        'image'      => $image,
				                                        'size'       => 'tiny',
				                                        'attributes' => [
					                                        'alt' => $image->title ?: $this->product->name,
				                                        ],
			                                        ]); ?>
                                                </a>
	                                        <?php endif; ?>
                                        </li>
									<?php endforeach; ?>
                                </ul>
                                <a class="uk-position-center-left uk-position-small uk-hidden-hover" href="#"
                                   uk-slidenav-previous uk-slider-item="previous"></a>
                                <a class="uk-position-center-right uk-position-small uk-hidden-hover" href="#"
                                   uk-slidenav-next uk-slider-item="next"></a>
                            </div>
                            <!--Dots-->
                            <!--<ul class="uk-slider-nav uk-dotnav uk-flex-center uk-margin"></ul>-->
                        </div>
					<?php endif; ?>
                </div>
            </div>
		<?php endif; ?>
        <div class="<?php echo $rightWidth; ?> product-summary uk-position-relative">

			<?php if (!empty($this->product->badgeData)): ?>
				<?php echo $renderer->render('product.badge.badge', $this->product->badgeData); ?>
			<?php endif; ?>

            <h1 itemprop="name" class="product-name" data-product-name>
				<?php echo $this->escape($this->product->name); ?>
				<?php echo $renderer->render('product.stock', [
					'product' => $this->product,
					'config'  => $config,
				]); ?>
            </h1>

			<?php echo $this->event->execute('onProductAfterDisplayName'); ?>

			<?php if ($config->get('product_detail_meta', 0)): ?>
				<?php echo $renderer->render('product.meta', [
					'product' => $this->product,
					'config'  => $config,
					'view'    => 'detail',
				]); ?>
			<?php endif; ?>

			<?php if ($config->get('product_detail_intro', 1) && !empty($this->product->summary)): ?>
                <div class="product-intro" itemprop="description" data-product-intro>
					<?php echo $this->product->summary; ?>
                </div>
			<?php endif; ?>

			<?php if ($config->get('product_detail_field', 'tab') == 'info'
				&& count($this->product->customfields)
			): ?>
                <div class="es-product-fields-info">
					<?php foreach ($this->product->customfields as $customfield): ?>
						<?php if (count($customfield['fields'])): ?>
                            <div class="uk-margin">
                                <div class="uk-heading-bullet">
									<?php echo $customfield['title']; ?>
                                </div>
								<?php echo $renderer->render('product.field.' . $customfield['params']->get('fields_output_layout', 'table'), [
									'fields' => $customfield['fields'],
								]); ?>
                            </div>
						<?php endif; ?>
					<?php endforeach; ?>
                </div>
				<?php echo $this->event->execute('onProductAfterDisplayFields'); ?>
			<?php endif; ?>

			<?php echo $renderer->render('product.price', [
				'product' => $this->product,
				'config'  => $config,
				'view'    => 'detail',
			]); ?>

			<?php

			if ($this->product->params->get('product_detail_add_to_cart', 1))
			{
				// @since 1.1.6
				if (!empty($this->product->options))
				{
					echo '<div class="product-options uk-form uk-margin-small-top" data-product-options>' . $this->product->options . '</div>';
				}

				$addToCartHtml = $renderer->render('cart.button.' . ($cartIconGroup ? 'icon' : 'normal'), [
					'product' => $this->product,
					'config'  => $config,
					'view'    => 'detail',
				]);

				if ($cartIconGroup)
				{
					$this->product->extraDetailFlexDisplay = array_merge([
						'addToCart' => $addToCartHtml,
					], $this->product->extraDetailFlexDisplay);
				}
				else
				{
					echo $addToCartHtml;
				}
			}

			?>

			<?php if ($this->product->extraDetailFlexDisplay): ?>
                <div class="es-extra-flex-display uk-flex">
					<?php echo join("\n", $this->product->extraDetailFlexDisplay); ?>
                </div>
			<?php endif; ?>

			<?php if ($this->product->extraDetailDisplay): ?>
				<?php echo join("\n", $this->product->extraDetailDisplay); ?>
			<?php endif; ?>

			<?php if ($config->get('product_detail_tags', 1) && !empty($this->product->productTags)): ?>
				<?php echo $renderer->render('product.tags', [
					'tags' => $this->product->productTags,
				]); ?>
			<?php endif; ?>

			<?php echo $this->event->execute('onProductAfterDisplaySummary'); ?>

			<?php if ($countdown): ?>
				<?php echo $renderer->render('product.countdown', [
					'product'        => $this->product,
					'showLabel'      => (int) $this->product->params->get('product_detail_countdown_show_label', 0),
					'countdownLabel' => (int) $this->product->params->get('product_detail_countdown_label', 0),
				]); ?>
			<?php endif; ?>
        </div>
    </div>
    <div class="uk-clearfix"></div>
	<?php JHtml::_('ukui.addTab', JText::_('COM_EASYSHOP_DESCRIPTION'), '<span uk-icon="icon: info"></span>'); ?>
    <div class="product-text">
		<?php echo $this->product->description; ?>
    </div>
	<?php JHtml::_('ukui.endTab'); ?>

	<?php if ($config->get('product_detail_field', 'tab') == 'tab'
		&& count($this->product->customfields)
	): ?>
		<?php foreach ($this->product->customfields as $customfield): ?>
			<?php if (count($customfield['fields'])): ?>
				<?php JHtml::_('ukui.addTab', $customfield['title']); ?>
				<?php echo $renderer->render('product.field.' . $customfield['params']->get('fields_output_layout', 'table'), [
					'fields' => $customfield['fields'],
				]); ?>
				<?php JHtml::_('ukui.endTab'); ?>
			<?php endif; ?>
		<?php endforeach; ?>
		<?php echo $this->event->execute('onProductAfterDisplayFields'); ?>
	<?php endif; ?>
	<?php echo $this->event->execute('onProductBeforeRenderTab'); ?>
	<?php echo JHtml::_('ukui.renderTab', 'tab-default', ['responsive' => true]); ?>
	<?php echo $this->event->execute('onProductAfterDisplay'); ?>
</div>
