<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.view.legacy');

use ES\View\ViewLegacy;

class EasyshopViewCart extends ViewLegacy
{
	/**
	 * @var $cart \ES\Cart
	 * @since 1.0.0
	 */
	protected $cart;
	protected $currency;
	protected $paymentMethods;
	protected $shippingMethods;
	protected $checkoutForm;
	protected $customerForm;
	protected $address = [
		'billing'  => '',
		'shipping' => '',
	];
	protected $cartData = [];
	protected $paymentActiveId = 0;
	protected $shippingActiveId = 0;

	public function display($tpl = null)
	{
		$user                  = JFactory::getUser();
		$app                   = JFactory::getApplication();
		$this->currency        = easyshop('class.currency')->getActive();
		$this->cart            = easyshop('class.cart');
		$model                 = easyshop('model', 'checkout');
		$this->cartData        = $this->cart->extractVendorData();
		$checkoutData          = $this->cart->getCheckoutData();
		$this->paymentMethods  = $this->cart->getPaymentMethods();
		$this->shippingMethods = $this->cart->getShippingMethods();
		JText::script('COM_EASYSHOP_ERROR_INVALID_CARD_NUMBER');

		$count = 0;

		if (!empty($this->cartData))
		{
			foreach ($this->cartData as $vendorId => $cartData)
			{
				$count += $cartData['count'];
			}
		}

		if (!$count)
		{
			$this->setLayout('empty');

			return parent::display($tpl);
		}

		if (empty($checkoutData['payment_id']))
		{
			foreach ($this->paymentMethods as $payment)
			{
				if ($payment->is_default)
				{
					$this->paymentActiveId = (int) $payment->id;
					break;
				}
			}
		}
		else
		{
			$this->paymentActiveId = (int) $checkoutData['payment_id'];
		}

		if (empty($checkoutData['shipping_id']))
		{
			foreach ($this->shippingMethods as $shipping)
			{
				if ($shipping->is_default)
				{
					$this->shippingActiveId = (int) $shipping->id;
					break;
				}
			}
		}
		else
		{
			$this->shippingActiveId = (int) $checkoutData['shipping_id'];
		}

		$layout = $this->getLayout();

		if (in_array($layout, ['login', 'checkout', 'confirm']))
		{
			$redirect = null;

			switch ($layout)
			{
				case 'login':
					if (!$user->guest)
					{
						$redirect = JRoute::_(EasyshopHelperRoute::getCartRoute('checkout'), false);
					}

					$this->customerForm = easyshop('model', 'customer', ES_COMPONENT_SITE)->getForm();
					break;

				case 'checkout':
					if ($user->guest && empty($checkoutData['guest']['email']))
					{
						$redirect = JRoute::_(EasyshopHelperRoute::getCartRoute('login'), false);
					}

					break;

				case 'confirm':
					if (empty($checkoutData['billing_address'])
						|| empty($checkoutData['shipping_address'])
					)
					{
						$redirect = JRoute::_(EasyshopHelperRoute::getCartRoute('checkout'), false);
						$app->enqueueMessage(JText::_('COM_EASYSHOP_WARNING_INVALID_CHECKOUT_DATA'), 'warning');
					}
					else
					{
						/**
						 * @var $customField \ES\CustomField
						 * @var $utility     \ES\Utility
						 */
						$customField     = easyshop('class.customField', [
							'reflector' => 'com_easyshop.user',
						]);
						$utility         = easyshop('class.utility');
						$billingAddress  = $customField->parseFormFieldData($checkoutData['billing_address']);
						$shippingAddress = $customField->parseFormFieldData($checkoutData['shipping_address']);
						$this->address   = [
							'billing'  => $utility->formatAddress($billingAddress),
							'shipping' => $utility->formatAddress($shippingAddress),
						];
					}

					break;
			}

			if (null !== $redirect)
			{
				$app->redirect($redirect);
			}
		}

		if ($layout == 'confirm' && ($finalData = $this->getFinalData()))
		{
			echo $finalData;
		}
		else
		{
			$this->checkoutForm = $model->getForm();

			parent::display($tpl);
		}
	}

	protected function getFinalData()
	{
		$data      = $this->cart->getCheckoutData();
		$finalData = null;

		if (isset($data['finalData']))
		{
			$finalData    = $data['finalData'];
			$vendorActive = $this->cart->getVendorActive();

			if (count($this->cartData) > 1 && isset($this->cartData[$vendorActive]['items']))
			{
				foreach ($this->cartData[$vendorActive]['items'] as $item)
				{
					$this->cart->removeItem($item['product']->id);
				}

				unset($data['finalData']);
				$this->cart->setCheckoutData($data);
			}
			else
			{
				$this->cart->destroy();
			}
		}

		return $finalData;
	}
}
