<?php

/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.view.legacy');

use ES\View\ViewLegacy;

class EasyshopViewProductDetail extends ViewLegacy
{
	protected $product;
	protected $event;
	protected $menuItem = null;

	public function display($tpl = null)
	{
		/**
		 * @var  $productClass \ES\Product
		 * @var  $user         \ES\User
		 * @var  $app          \JApplicationCms
		 */
		$productClass  = easyshop('class.product');
		$app           = easyshop('app');
		$user          = easyshop('class.user');
		$pk            = $app->input->getInt('id');
		$menu          = $app->getMenu()->getActive();
		$this->product = $productClass->getItem($pk);

		if ((int) $this->product->state !== 1 && !$user->core('admin'))
		{
			$user->stop();
		}

		$app->triggerEvent('onEasyshopPrepareItem', ['com_easyshop.product', $this->product]);
		$ignoreNames = [];

		foreach ($this->product->params->toArray() as $name => $value)
		{
			if (trim($value) !== '' && $this->config->exists($name))
			{
				$this->config->set($name, $value);
				$ignoreNames[] = $name;
			}
		}

		if ($menu
			&& @$menu->query['option'] == 'com_easyshop'
			&& @$menu->query['view'] == 'productdetail'
			&& @$menu->query['id'] == $this->product->id
		)
		{
			$this->menuItem = $menu;

			foreach ($menu->params->toArray() as $name => $value)
			{
				if (!in_array($name, $ignoreNames)
					&& trim($value) !== ''
					&& $this->config->exists($name)
				)
				{
					$this->config->set($name, $value);
				}
			}
		}

		if (true === $this->product->expireDate)
		{
			$app->enqueueMessage(JText::_('COM_EASYSHOP_WARNING_PRODUCT_NOT_ENABLED'), 'warning');
		}

		if ($this->config->get('product_detail_prepare', 0))
		{
			$this->product->description = JHtml::_('content.prepare', $this->product->description, null, 'com_easyshop.product');
		}

		$app->triggerEvent('onProductAddonDisplay', [$this->product]);
		$this->event = easyshop('class.event');
		$this->event->register('onProductBeforeDisplay', [$this->product]);
		$this->event->register('onProductAfterDisplayName', [$this->product]);
		$this->event->register('onProductAfterDisplaySummary', [$this->product]);
		$this->event->register('onProductAfterDisplayFields', [$this->product]);
		$this->event->register('onProductBeforeRenderTab', [$this->product]);
		$this->event->register('onProductAfterDisplay', [$this->product]);

		// @since 1.1.6 Apply Images Lazy Load
		if ($this->config->get('image_advance_mode', '0')
			&& strpos($this->product->description, 'src=') !== false
		)
		{
			$rootUrl = JUri::root(true) . '/';
			$regex   = '#\ssrc="(?!/|[a-zA-Z0-9\-]+:|\#|\')([^"]*)"#m';

			$this->product->description = preg_replace($regex, ' src="' . $rootUrl . '$1"', $this->product->description);
			$this->product->description = preg_replace('/\<img(.*)src=\"([^\"]+)\"([^\>]*)\>/', '<img$1data-src="$2" uk-img$3>', $this->product->description);
		}

		if (!empty($this->product->badgeData))
		{
			if (empty($this->product->badgeData['badge_detail_position']))
			{
				unset($this->product->badgeData);
			}
			else
			{
				$this->product->badgeData['badge_position'] = $this->product->badgeData['badge_detail_position'];
			}
		}

		$this->_prepareDocument();
		parent::display($tpl);
	}

	protected function _prepareDocument()
	{
		$document = easyshop('doc');

		if ($document->getType() != 'html')
		{
			return;
		}

		$app      = easyshop('app');
		$pathway  = $app->getPathway();
		$domain   = JUri::getInstance()->toString(['scheme', 'host']);
		$title    = trim($this->product->metatitle);
		$metaDesc = trim($this->product->metadesc);
		$metaKey  = trim($this->product->metakey);

		if ($menu = $app->getMenu()->getActive())
		{
			$id     = isset($menu->query['id']) ? (int) $menu->query['id'] : 0;
			$option = isset($menu->query['option']) ? $menu->query['option'] : '';
			$view   = isset($menu->query['view']) ? $menu->query['view'] : '';

			if ($option !== 'com_easyshop' || $view === 'productlist')
			{
				$path = [
					[
						'title' => $this->product->name,
						'link'  => '',
					],
				];

				if ($view === 'productlist')
				{
					$category = $this->product->category;

					while ($category && $id != $category->id && $category->id > 1)
					{
						$path[]   = [
							'title' => $category->title,
							'link'  => EasyshopHelperRoute::getCategoryRoute($category->id),
						];
						$category = $category->getParent();
					}

				}

				$path = array_reverse($path);

				foreach ($path as $item)
				{
					$pathway->addItem($item['title'], $item['link']);
				}
			}

			if ($this->menuItem)
			{
				if (empty($title) && $this->menuItem->params->get('page_title', ''))
				{
					$title = $this->menuItem->params->get('page_title');
				}

				if (empty($metaDesc) && $this->menuItem->params->get('menu-meta_description'))
				{
					$metaDesc = $this->menuItem->params->get('menu-meta_description');
				}

				if (empty($metaKey) && $this->menuItem->params->get('menu-meta_keywords'))
				{
					$metaKey = $this->menuItem->params->get('menu-meta_keywords');
				}
			}
		}

		if (empty($title))
		{
			$title = trim($this->product->name);
		}

		if (empty($metaDesc))
		{
			$metaDesc = trim(strip_tags(substr($this->product->summary, 0, 159)));
		}

		if ($app->get('sitename_pagetitles', 0) == 1)
		{
			$title = JText::sprintf('JPAGETITLE', $app->get('sitename'), $title);
		}
		elseif ($app->get('sitename_pagetitles', 0) == 2)
		{
			$title = JText::sprintf('JPAGETITLE', $title, $app->get('sitename'));
		}

		$document->setTitle($title);
		$document->setDescription($metaDesc);
		$document->setMetadata('keywords', $metaKey);

		if (isset($this->product->images[0]->image))
		{
			$document->setMetadata('og:image', $domain . $this->product->images[0]->image, 'property');
		}

		$document->addHeadLink(htmlspecialchars($domain . $this->product->link), 'canonical');
		$document->setMetadata('og:url', $domain . $this->product->link, 'property');
		$document->setMetadata('og:title', $title, 'property');
		$document->setMetadata('og:type', 'product', 'property');
		$document->setMetadata('og:description', trim($metaDesc), 'property');

		if (!empty($this->product->robots))
		{
			$document->setMetadata('robots', trim($this->product->robots));
		}

		if ($app->get('MetaAuthor') == '1' && !empty($this->product->author))
		{
			$document->setMetaData('author', trim($this->product->author));
		}
	}
}
