<?php
/**
 * @package     com_easyshop
 * @version     1.2.3
 * @Author      JoomTech Team
 * @copyright   Copyright (C) 2015 - 2019 www.joomtech.net All Rights Reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die;
JLoader::import('easyshop.view.list');

use ES\View\ViewList;
use Joomla\Registry\Registry;

class EasyshopViewProductList extends ViewList
{
	protected $showNavbar = false;
	protected $useFilter = false;
	protected $addToolbar = false;
	protected $filters = [];
	protected $category;
	protected $menuItem = null;

	public function display($tpl = null)
	{
		$app   = easyshop('app');
		$menu  = $app->getMenu('site')->getActive();
		$model = easyshop('model', 'products', ES_COMPONENT_ADMINISTRATOR);
		$model->setState('filter.published', 1);
		$categoryId = (int) $app->input->getInt('id');
		$nodes      = JCategories::getInstance('easyshop.product');
		$category   = $nodes->get($categoryId);

		if ($categoryId < 1 || !$category)
		{
			throw new RuntimeException(JText::_('COM_EASYSHOP_ERROR_CATEGORY_NOT_FOUND'));
		}

		$category->params = new Registry($category->params);
		$ignoreNames      = [];

		foreach ($category->params->toArray() as $name => $value)
		{
			if ($this->config->exists($name) && trim($value) !== '')
			{
				$this->config->set($name, $value);
				$ignoreNames[] = $name;
			}
		}

		if ($menu
			&& @$menu->query['option'] == 'com_easyshop'
			&& @$menu->query['view'] == 'productlist'
		)
		{
			if (@$menu->query['id'] == $categoryId)
			{
				$this->menuItem = $menu;
			}

			foreach ($menu->params->toArray() as $name => $value)
			{
				if (!in_array($name, $ignoreNames)
					&& $this->config->exists($name)
					&& trim($value) !== ''
				)
				{
					$this->config->set($name, $value);
				}
			}
		}

		$model->setState('filter.category_id', $categoryId);
		$model->setState('filter.include_sub_categories', (int) $this->config->get('product_in_sub_categories'));
		$model->setState('filter.language', JLanguageMultilang::isEnabled());
		$limitList      = $this->config->get('list_limit');
		$this->category = $category;
		$this->filters  = array_merge(
			['sort' => 'ordering', 'display' => (int) $limitList[0]],
			(array) $app->getUserState('com_easyshop.product_filter_list', [])
		);
		/** @var $utility \ES\Utility */
		$utility = easyshop('class.utility');
		$utility->parseOrderingData($this->filters['sort'], $ordering, $direction);
		$display = abs((int) $this->filters['display']);
		$model->setState('list.ordering', $ordering);
		$model->setState('list.direction', $direction);
		$model->setState('list.start', $app->input->get('limitstart', 0, 'uint'));
		$model->setState('list.limit', $display > 0 ? $display : (int) $limitList[0]);
		$this->setModel($model, true);
		$displayMode = $this->config->get('list_mode', 'toggle');

		if ($displayMode != 'toggle')
		{
			$this->document->addScriptDeclaration('_es.storage.setData("list.view", "' . $displayMode . '");');
		}

		$this->prepareDocument();

		parent::display($tpl);
	}

	protected function beforeDisplay()
	{
		if (!empty($this->items))
		{
			easyshop('prepare.product', $this->items);
		}
	}

	protected function prepareDocument()
	{
		$document = easyshop('doc');

		if ($document->getType() != 'html')
		{
			return;
		}

		$app      = easyshop('app');
		$pathway  = $app->getPathway();
		$title    = trim($this->category->title);
		$metaDesc = trim($this->category->metadesc);
		$metaKey  = trim($this->category->metakey);
		$domain   = JUri::getInstance()->toString(['scheme', 'host']);
		$document->addHeadLink(htmlspecialchars($domain . EasyshopHelperRoute::getCategoryRoute($this->category->id)), 'canonical');

		if ($this->menuItem)
		{
			if ($this->menuItem->params->get('page_title', ''))
			{
				$title = $this->menuItem->params->get('page_title');
			}

			if ($this->menuItem->params->get('menu-meta_description'))
			{
				$metaDesc = $this->menuItem->params->get('menu-meta_description');
			}

			if ($this->menuItem->params->get('menu-meta_keywords'))
			{
				$metaKey = $this->menuItem->params->get('menu-meta_keywords');
			}
		}

		if (empty($metaDesc))
		{
			$category = $this->category;

			while ($category && empty($metaDesc))
			{
				$category = $category->getParent();
				$metaDesc = $category ? $category->metadesc : $metaDesc;
			}
		}

		if (empty($metaKey))
		{
			$category = $this->category;

			while ($category && empty($metaKey))
			{
				$category = $category->getParent();
				$metaKey  = $category ? $category->metakey : $metaKey;
			}
		}

		if ($app->get('sitename_pagetitles', 0) == 1)
		{
			$title = JText::sprintf('JPAGETITLE', $app->get('sitename'), $title);
		}
		elseif ($app->get('sitename_pagetitles', 0) == 2)
		{
			$title = JText::sprintf('JPAGETITLE', $title, $app->get('sitename'));
		}

		$document->setTitle($title);

		if ($metaDesc)
		{
			$document->setDescription($metaDesc);
		}

		if ($metaKey)
		{
			$document->setMetadata('keywords', $metaKey);
		}

		if ($this->category->params->get('robots'))
		{
			$document->setMetadata('robots', $this->category->params->get('robots'));
		}

		if (!is_object($this->category->metadata))
		{
			$this->category->metadata = new Registry($this->category->metadata);
		}

		if (($app->get('MetaAuthor') == '1') && $this->category->get('author', ''))
		{
			$document->setMetaData('author', $this->category->get('author', ''));
		}

		foreach ($this->category->metadata->toArray() as $k => $v)
		{
			if ($v)
			{
				$document->setMetadata($k, $v);
			}
		}

		if ($menu = $app->getMenu()->getActive())
		{
			$id     = isset($menu->query['id']) ? (int) $menu->query['id'] : 0;
			$option = isset($menu->query['option']) ? $menu->query['option'] : '';
			$view   = isset($menu->query['view']) ? $menu->query['view'] : '';

			if ($option !== 'com_easyshop'
				|| ($view === 'productlist' && $id != $this->category->id)
				|| $view === 'productdetail'
			)
			{
				$path     = [
					[
						'title' => $this->category->title,
						'link'  => '',
					],
				];
				$category = $this->category->getParent();

				if ($view === 'productdetail')
				{
					while ($category && $category->id > 1)
					{
						$path[]   = [
							'title' => $category->title,
							'link'  => EasyshopHelperRoute::getCategoryRoute($category->id),
						];
						$category = $category->getParent();
					}
				}
				elseif ($view === 'productlist')
				{
					while ($category && $id != $category->id && $category->id > 1)
					{
						$path[]   = [
							'title' => $category->title,
							'link'  => EasyshopHelperRoute::getCategoryRoute($category->id),
						];
						$category = $category->getParent();
					}
				}

				$path = array_reverse($path);

				foreach ($path as $item)
				{
					$pathway->addItem($item['title'], $item['link']);
				}
			}
		}
	}
}
